      module ross_tables

!.... BOB PREFERS FIORELLA'S ODFs, SO USE HER ROSSELAND TABLE AS THE DEFAULT
!.... 2012 FEB - CORRECTED H2O FROM BOB

      use var_types

      implicit none

!------------------------------ CONSTANTS ------------------------------

      integer(in_type), parameter :: np_ross_c = 42 !#CASTELLI PRESSURES
      integer(in_type), parameter :: np_ross_k = 38 !# KURUCZ PRESSURES

      integer(in_type), parameter :: nt_ross_c = 57 !# CASTELLI TEMP
      integer(in_type), parameter :: nt_ross_k = 56 !# KURUCZ TEMP

      integer(in_type), parameter :: nv_ross = 5    !# VELOCITIES

!------------------------------ VARIABLES ------------------------------

      integer(in_type) :: np_ross ! VALUE IS DEFINED IN rosstab
      integer(in_type) :: nt_ross ! VALUE IS DEFINED IN rosstab

!.... DEFINE ross_default WITH THE LARGER CASTELLI DIMENSIONS

      integer(in_type) :: ross_default(nt_ross_c, np_ross_c, nv_ross)
!!!!  integer(in_type) :: ross_default(nt_ross_k, np_ross_k, nv_ross)

      logical :: if_ross = .false.

      real(re_type) :: p_ross(np_ross_c) ! DEFINE USING CASTELLI DIM

!.... CASTELLI PRESSURES = 4 MORE THAN KURUCZ

      real(re_type) :: p_ross_c(np_ross_c) = [
     &  -4.00, -3.50, -3.00, -2.50,
     &  -2.00, -1.50, -1.00, -0.50,  0.00,
     &   0.50,  1.00,  1.25,  1.50,  1.75,
     &   2.00,  2.25,  2.50,  2.75,  3.00,
     &   3.20,  3.40,  3.60,  3.80,  4.00,
     &   4.20,  4.40,  4.60,  4.80,  5.00,
     &   5.20,  5.40,  5.60,  5.80,  6.00,
     &   6.25,  6.50,  6.75,  7.00,  7.25,
     &   7.50,  7.75,  8.00 ]

!.... KURUCZ PRESSURES

      real(re_type) :: p_ross_k(np_ross_k) = [
     &  -2.00, -1.50, -1.00, -0.50,  0.00,
     &   0.50,  1.00,  1.25,  1.50,  1.75,
     &   2.00,  2.25,  2.50,  2.75,  3.00,
     &   3.20,  3.40,  3.60,  3.80,  4.00,
     &   4.20,  4.40,  4.60,  4.80,  5.00,
     &   5.20,  5.40,  5.60,  5.80,  6.00,
     &   6.25,  6.50,  6.75,  7.00,  7.25,
     &   7.50,  7.75,  8.00 ]

      real(re_type) :: ross_tab(nt_ross_c, np_ross_c, nv_ross)

      real(re_type) :: t_ross(nt_ross_c) ! DEFINE USING CASTELLI DIM

!.... CASTELLI TEMPERATURES = 1 MORE THAN KURUCZ

      real(re_type) :: t_ross_c(nt_ross_c) = [
     &   3.30,
     &   3.32, 3.34, 3.36, 3.38, 3.40, 3.42, 3.44, 3.46, 3.48, 3.50,
     &   3.52, 3.54, 3.56, 3.58, 3.60, 3.62, 3.64, 3.66, 3.68, 3.70,
     &   3.73, 3.76, 3.79, 3.82, 3.85, 3.88, 3.91, 3.94, 3.97, 4.00,
     &   4.05, 4.10, 4.15, 4.20, 4.25, 4.30, 4.35, 4.40, 4.45, 4.50,
     &   4.55, 4.60, 4.65, 4.70, 4.75, 4.80, 4.85, 4.90, 4.95, 5.00,
     &   5.05, 5.10, 5.15, 5.20, 5.25, 5.30 ]

!.... KURUCZ TEMPERATURES

      real(re_type) :: t_ross_k(nt_ross_k) = [
     &   3.32, 3.34, 3.36, 3.38, 3.40, 3.42, 3.44, 3.46, 3.48, 3.50,
     &   3.52, 3.54, 3.56, 3.58, 3.60, 3.62, 3.64, 3.66, 3.68, 3.70,
     &   3.73, 3.76, 3.79, 3.82, 3.85, 3.88, 3.91, 3.94, 3.97, 4.00,
     &   4.05, 4.10, 4.15, 4.20, 4.25, 4.30, 4.35, 4.40, 4.45, 4.50,
     &   4.55, 4.60, 4.65, 4.70, 4.75, 4.80, 4.85, 4.90, 4.95, 5.00,
     &   5.05, 5.10, 5.15, 5.20, 5.25, 5.30 ]

      real(re_type) :: v_ross(nv_ross) = [
     &  0.0E+0, 1.0E+5, 2.0E+5, 4.0E+5, 8.0E+5 ]

!---------------------------- INITIALIZATION ---------------------------

!.... DEFAULT ROSSELAND TABLE = SOLAR COMPOSITION FROM CASTELLI

      data ross_default(1:nt_ross_c,  1, 1) /                     !-4.00
     &-5110,-4979,-4809,-4630,-4471,-4353,-4277,-4244,-4234,-4220,!-4.00
     &-4169,-4035,-3804,-3503,-3157,-2785,-2404,-2025,-1658,-1306,!-4.00
     & -985, -647, -539, -522, -523, -526, -527, -525, -509, -495,!-4.00
     & -490, -485, -487, -488, -484, -478, -455, -450, -446, -442,!-4.00
     & -434, -423, -409, -388, -355, -307, -241, -156,  -57,   44,!-4.00
     &  124,  160,  144,   94,   31,  -23,  -63/                  !-4.00

      data ross_default(1:nt_ross_c,  2, 1) /                     !-3.50
     &-5119,-5039,-4888,-4717,-4546,-4404,-4302,-4244,-4223,-4215,!-3.50
     &-4190,-4109,-3932,-3669,-3350,-2999,-2632,-2262,-1898,-1545,!-3.50
     &-1210, -787, -573, -525, -519, -522, -525, -526, -517, -498,!-3.50
     & -490, -484, -483, -486, -483, -479, -458, -449, -445, -440,!-3.50
     & -434, -422, -407, -387, -354, -307, -241, -156,  -57,   44,!-3.50
     &  124,  160,  144,   94,   31,  -23,  -63/                  !-3.50

      data ross_default(1:nt_ross_c,  3, 1) /                     !-3.00
     &-5093,-5068,-4955,-4799,-4630,-4469,-4343,-4257,-4214,-4203,!-3.00
     &-4192,-4150,-4032,-3815,-3529,-3201,-2851,-2492,-2135,-1784,!-3.00
     &-1446, -982, -655, -538, -516, -517, -521, -523, -521, -505,!-3.00
     & -491, -483, -479, -483, -482, -477, -464, -448, -444, -439,!-3.00
     & -433, -421, -406, -386, -354, -306, -241, -156,  -56,   44,!-3.00
     &  124,  160,  144,   94,   31,  -23,  -63/                  !-3.00

      data ross_default(1:nt_ross_c,  4, 1) /                     !-2.50
     &-4986,-5054,-5002,-4869,-4713,-4546,-4399,-4287,-4216,-4188,!-2.50
     &-4181,-4163,-4096,-3937,-3690,-3390,-3060,-2715,-2366,-2020,!-2.50
     &-1684,-1205, -802, -578, -518, -510, -514, -519, -520, -513,!-2.50
     & -494, -482, -474, -478, -480, -476, -467, -447, -442, -437,!-2.50
     & -432, -421, -404, -384, -353, -306, -240, -155,  -56,   44,!-2.50
     &  124,  160,  144,   94,   31,  -23,  -63/                  !-2.50

      data ross_default(1:nt_ross_c,  5, 1) /                     !-2.00
     &-4696,-4958,-5007,-4924,-4785,-4627,-4467,-4331,-4233,-4178,!-2.00
     &-4162,-4156,-4125,-4026,-3830,-3563,-3255,-2927,-2589,-2251,!-2.00
     &-1918,-1436, -997, -670, -532, -503, -504, -510, -515, -514,!-2.00
     & -500, -480, -471, -471, -476, -473, -466, -447, -440, -435,!-2.00
     & -429, -420, -403, -382, -352, -306, -240, -155,  -56,   44,!-2.00
     &  124,  160,  144,   94,   31,  -23,  -63/                  !-2.00

      data ross_default(1:nt_ross_c,  6, 1) /                     !-1.50
     &-4146,-4681,-4922,-4944,-4841,-4700,-4542,-4389,-4265,-4181,!-1.50
     &-4142,-4135,-4125,-4075,-3940,-3716,-3436,-3127,-2803,-2475,!-1.50
     &-2147,-1667,-1212, -819, -576, -498, -488, -495, -504, -509,!-1.50
     & -503, -479, -467, -462, -470, -470, -464, -449, -437, -433,!-1.50
     & -426, -418, -402, -381, -350, -305, -240, -154,  -55,   45,!-1.50
     &  124,  160,  144,   94,   31,  -23,  -63/                  !-1.50

      data ross_default(1:nt_ross_c,  7, 1) /                     !-1.00
     &-3439,-4139,-4652,-4872,-4867,-4754,-4611,-4453,-4308,-4196,!-1.00
     &-4127,-4103,-4101,-4083,-4009,-3840,-3596,-3311,-3004,-2687,!-1.00
     &-2368,-1892,-1431,-1002, -666, -500, -462, -466, -481, -493,!-1.00
     & -497, -477, -463, -452, -458, -464, -459, -449, -433, -429,!-1.00
     & -423, -416, -401, -379, -348, -304, -239, -154,  -54,   45,!-1.00
     &  124,  160,  144,   94,   31,  -23,  -63/                  !-1.00

      data ross_default(1:nt_ross_c,  8, 1) /                     !-0.50
     &-2770,-3434,-4109,-4601,-4803,-4775,-4657,-4509,-4352,-4215,!-0.50
     &-4116,-4064,-4054,-4054,-4026,-3922,-3726,-3471,-3184,-2883,!-0.50
     &-2573,-2105,-1642,-1196, -797, -524, -421, -412, -432, -455,!-0.50
     & -472, -470, -455, -442, -443, -452, -451, -444, -429, -424,!-0.50
     & -419, -412, -399, -377, -346, -302, -238, -154,  -53,   46,!-0.50
     &  124,  160,  144,   94,   31,  -23,  -63/                  !-0.50

      data ross_default(1:nt_ross_c,  9, 1) /                     ! 0.00
     &-2313,-2763,-3401,-4046,-4524,-4705,-4661,-4535,-4379,-4224,! 0.00
     &-4096,-4011,-3979,-3982,-3984,-3939,-3806,-3591,-3331,-3047,! 0.00
     &-2751,-2295,-1834,-1377, -942, -579, -372, -320, -337, -374,! 0.00
     & -410, -442, -436, -428, -422, -434, -438, -434, -423, -416,! 0.00
     & -413, -406, -396, -374, -344, -300, -237, -153,  -52,   47,! 0.00
     &  125,  160,  144,   94,   31,  -23,  -63/                  ! 0.00

      data ross_default(1:nt_ross_c, 10, 1) /                     ! 0.50
     &-2129,-2283,-2731,-3334,-3953,-4406,-4564,-4507,-4368,-4203,! 0.50
     &-4049,-3933,-3866,-3852,-3867,-3867,-3802,-3642,-3416,-3154,! 0.50
     &-2875,-2438,-1985,-1524,-1068, -648, -332, -190, -181, -225,! 0.50
     & -283, -363, -390, -397, -393, -405, -415, -415, -409, -403,! 0.50
     & -403, -398, -390, -371, -341, -297, -236, -152,  -51,   49,! 0.50
     &  126,  160,  144,   94,   31,  -23,  -63/                  ! 0.50

      data ross_default(1:nt_ross_c, 11, 1) /                     ! 1.00
     &-2073,-2071,-2240,-2667,-3235,-3814,-4233,-4366,-4290,-4136,! 1.00
     &-3964,-3815,-3709,-3659,-3662,-3684,-3676,-3585,-3405,-3170,! 1.00
     &-2911,-2498,-2063,-1610,-1148, -698, -304,  -44,   38,    7,! 1.00
     &  -64, -198, -285, -325, -343, -359, -380, -383, -381, -379,! 1.00
     & -385, -386, -380, -366, -337, -294, -233, -151,  -51,   51,! 1.00
     &  128,  161,  144,   94,   31,  -24,  -63/                  ! 1.00

      data ross_default(1:nt_ross_c, 12, 1) /                     ! 1.25
     &-2064,-2037,-2123,-2416,-2897,-3456,-3951,-4209,-4206,-4075,! 1.25
     &-3902,-3739,-3616,-3545,-3531,-3551,-3562,-3506,-3355,-3137,! 1.25
     &-2888,-2488,-2065,-1622,-1164, -708, -289,   22,  161,  154,! 1.25
     &   80,  -76, -199, -264, -301, -325, -353, -362, -361, -361,! 1.25
     & -370, -376, -373, -362, -334, -292, -231, -150,  -50,   53,! 1.25
     &  129,  162,  145,   94,   31,  -24,  -63/                  ! 1.25

      data ross_default(1:nt_ross_c, 13, 1) /                     ! 1.50
     &-2054,-2003,-2011,-2179,-2576,-3096,-3624,-3997,-4094,-3996,! 1.50
     &-3826,-3652,-3509,-3416,-3382,-3395,-3417,-3392,-3274,-3077,! 1.50
     &-2839,-2452,-2041,-1611,-1162, -705, -271,   84,  284,  315,! 1.50
     &  249,   73,  -87, -182, -242, -278, -318, -336, -335, -336,! 1.50
     & -350, -362, -363, -356, -331, -289, -229, -148,  -49,   54,! 1.50
     &  131,  162,  145,   94,   31,  -24,  -63/                  ! 1.50

      data ross_default(1:nt_ross_c, 14, 1) /                     ! 1.75
     &-2050,-1992,-1972,-2059,-2331,-2766,-3269,-3708,-3915,-3882,! 1.75
     &-3731,-3552,-3394,-3282,-3226,-3223,-3246,-3245,-3163,-2990,! 1.75
     &-2766,-2392,-1994,-1577,-1140, -690, -248,  138,  396,  479,! 1.75
     &  433,  248,   54,  -75, -163, -218, -270, -301, -304, -305,! 1.75
     & -321, -342, -350, -347, -326, -286, -226, -146,  -48,   55,! 1.75
     &  133,  164,  145,   94,   31,  -24,  -63/                  ! 1.75

      data ross_default(1:nt_ross_c, 15, 1) /                     ! 2.00
     &-2045,-1980,-1933,-1944,-2101,-2452,-2914,-3382,-3693,-3743,! 2.00
     &-3620,-3442,-3270,-3138,-3060,-3039,-3057,-3071,-3023,-2880,! 2.00
     &-2673,-2312,-1927,-1524,-1101, -661, -218,  187,  495,  638,! 2.00
     &  626,  445,  222,   54,  -62, -139, -206, -255, -267, -267,! 2.00
     & -283, -314, -331, -335, -319, -282, -223, -144,  -47,   56,! 2.00
     &  136,  165,  146,   94,   31,  -24,  -63/                  ! 2.00

      data ross_default(1:nt_ross_c, 16, 1) /                     ! 2.25
     &-2043,-1974,-1919,-1901,-1981,-2219,-2597,-3036,-3407,-3551,! 2.25
     &-3482,-3318,-3140,-2993,-2895,-2852,-2856,-2876,-2856,-2747,! 2.25
     &-2562,-2218,-1845,-1455,-1047, -619, -182,  233,  577,  780,! 2.25
     &  816,  655,  415,  211,   64,  -41, -125, -194, -219, -222,! 2.25
     & -236, -274, -303, -316, -308, -275, -219, -141,  -45,   57,! 2.25
     &  139,  167,  147,   94,   31,  -23,  -63/                  ! 2.25

      data ross_default(1:nt_ross_c, 17, 1) /                     ! 2.50
     &-2039,-1969,-1905,-1860,-1868,-1999,-2295,-2692,-3093,-3330,! 2.50
     &-3328,-3185,-3006,-2845,-2727,-2663,-2650,-2667,-2669,-2595,! 2.50
     &-2435,-2111,-1750,-1373, -980, -567, -139,  279,  647,  902,! 2.50
     &  996,  874,  626,  389,  214,   77,  -24, -115, -160, -168,! 2.50
     & -177, -222, -265, -290, -293, -266, -214, -137,  -42,   59,! 2.50
     &  141,  170,  148,   95,   32,  -23,  -63/                  ! 2.50

      data ross_default(1:nt_ross_c, 18, 1) /                     ! 2.75
     &-2033,-1963,-1896,-1842,-1822,-1884,-2078,-2391,-2763,-3057,! 2.75
     &-3135,-3034,-2865,-2697,-2563,-2479,-2447,-2453,-2464,-2423,! 2.75
     &-2294,-1995,-1647,-1281, -902, -504,  -89,  325,  707, 1002,! 2.75
     & 1154, 1092,  850,  590,  387,  222,   95,  -15,  -82, -102,! 2.75
     & -111, -153, -210, -252, -268, -252, -205, -131,  -38,   62,! 2.75
     &  145,  175,  150,   96,   32,  -23,  -63/                  ! 2.75

      data ross_default(1:nt_ross_c, 19, 1) /                     ! 3.00
     &-2028,-1957,-1888,-1825,-1778,-1775,-1873,-2106,-2434,-2762,! 3.00
     &-2922,-2876,-2722,-2549,-2402,-2298,-2245,-2237,-2250,-2234,! 3.00
     &-2139,-1870,-1537,-1183, -816, -433,  -32,  375,  762, 1085,! 3.00
     & 1290, 1304, 1080,  806,  577,  388,  238,  107,   13,  -23,! 3.00
     &  -33,  -70, -140, -199, -234, -232, -193, -124,  -33,   65,! 3.00
     &  148,  180,  153,   97,   32,  -23,  -63/                  ! 3.00

      data ross_default(1:nt_ross_c, 20, 1) /                     ! 3.20
     &-2019,-1949,-1880,-1815,-1760,-1735,-1785,-1946,-2209,-2516,! 3.20
     &-2722,-2727,-2598,-2430,-2276,-2159,-2091,-2069,-2076,-2073,! 3.20
     &-2004,-1764,-1445,-1100, -742, -371,   17,  416,  804, 1141,! 3.20
     & 1379, 1464, 1265,  989,  744,  539,  380,  227,  109,   54,! 3.20
     &   37,    6,  -68, -142, -194, -207, -179, -115,  -27,   69,! 3.20
     &  152,  185,  156,   98,   33,  -23,  -63/                  ! 3.20

      data ross_default(1:nt_ross_c, 21, 1) /                     ! 3.40
     &-2009,-1940,-1872,-1805,-1743,-1697,-1701,-1793,-1992,-2269,! 3.40
     &-2508,-2571,-2473,-2311,-2152,-2023,-1940,-1903,-1902,-1905,! 3.40
     &-1861,-1653,-1349,-1014, -665, -305,   72,  461,  845, 1191,! 3.40
     & 1456, 1611, 1449, 1176,  916,  701,  542,  366,  220,  145,! 3.40
     &  118,   92,   15,  -73, -143, -175, -159, -103,  -19,   75,! 3.40
     &  156,  191,  160,  100,   34,  -22,  -62/                  ! 3.40

      data ross_default(1:nt_ross_c, 22, 1) /                     ! 3.60
     &-1995,-1928,-1860,-1792,-1726,-1667,-1639,-1677,-1814,-2041,! 3.60
     &-2286,-2399,-2339,-2190,-2029,-1891,-1795,-1743,-1730,-1734,! 3.60
     &-1709,-1536,-1250, -925, -585, -235,  130,  509,  887, 1237,! 3.60
     & 1522, 1743, 1629, 1366, 1097,  872,  701,  521,  348,  253,! 3.60
     &  211,  186,  111,   11,  -78, -131, -132,  -87,   -8,   82,! 3.60
     &  161,  197,  166,  103,   35,  -22,  -62/                  ! 3.60

      data ross_default(1:nt_ross_c, 23, 1) /                     ! 3.80
     &-1977,-1912,-1845,-1778,-1711,-1645,-1597,-1596,-1672,-1839,! 3.80
     &-2061,-2211,-2194,-2066,-1907,-1763,-1654,-1589,-1563,-1562,! 3.80
     &-1549,-1412,-1147, -833, -503, -162,  192,  559,  930, 1281,! 3.80
     & 1578, 1859, 1803, 1558, 1284, 1051,  854,  689,  494,  378,! 3.80
     &  319,  289,  222,  110,    2,  -73,  -95,  -65,    5,   92,! 3.80
     &  169,  205,  173,  106,   37,  -21,  -61/                  ! 3.80

      data ross_default(1:nt_ross_c, 24, 1) /                     ! 4.00
     &-1960,-1896,-1831,-1765,-1695,-1623,-1558,-1519,-1538,-1645,! 4.00
     &-1835,-2012,-2045,-1941,-1787,-1638,-1518,-1439,-1400,-1391,! 4.00
     &-1385,-1282,-1040, -739, -418,  -86,  257,  613,  975, 1324,! 4.00
     & 1630, 1959, 1966, 1749, 1474, 1233, 1016,  867,  652,  518,! 4.00
     &  442,  405,  343,  224,   98,   -2,  -48,  -36,   23,  105,! 4.00
     &  178,  213,  182,  111,   39,  -19,  -61/                  ! 4.00

      data ross_default(1:nt_ross_c, 25, 1) /                     ! 4.20
     &-1937,-1876,-1812,-1747,-1678,-1604,-1531,-1474,-1460,-1516,! 4.20
     &-1652,-1814,-1879,-1806,-1664,-1514,-1390,-1297,-1244,-1224,! 4.20
     &-1217,-1142, -928, -641, -329,   -7,  325,  670, 1022, 1366,! 4.20
     & 1676, 2041, 2117, 1937, 1671, 1423, 1206, 1029,  826,  679,! 4.20
     &  584,  533,  477,  355,  212,   88,   15,    5,   49,  123,! 4.20
     &  192,  225,  194,  118,   43,  -17,  -59/                  ! 4.20

      data ross_default(1:nt_ross_c, 26, 1) /                     ! 4.40
     &-1916,-1857,-1793,-1730,-1662,-1587,-1507,-1433,-1387,-1394,! 4.40
     &-1475,-1613,-1706,-1669,-1541,-1392,-1264,-1159,-1092,-1060,! 4.40
     &-1048, -995, -811, -540, -239,   73,  396,  730, 1072, 1410,! 4.40
     & 1720, 2115, 2252, 2120, 1867, 1615, 1396, 1200, 1008,  850,! 4.40
     &  739,  674,  620,  498,  342,  194,   92,   57,   82,  146,! 4.40
     &  209,  238,  209,  128,   48,  -14,  -57/                  ! 4.40

      data ross_default(1:nt_ross_c, 27, 1) /                     ! 4.60
     &-1892,-1836,-1774,-1712,-1645,-1570,-1486,-1401,-1332,-1301,! 4.60
     &-1334,-1435,-1533,-1526,-1417,-1272,-1138,-1024, -944, -899,! 4.60
     & -880, -841, -687, -435, -146,  157,  470,  794, 1125, 1455,! 4.60
     & 1764, 2178, 2371, 2295, 2063, 1810, 1591, 1386, 1200, 1034,! 4.60
     &  909,  830,  772,  655,  487,  318,  188,  124,  127,  175,! 4.60
     &  231,  257,  226,  141,   55,  -10,  -54/                  ! 4.60

      data ross_default(1:nt_ross_c, 28, 1) /                     ! 4.80
     &-1865,-1812,-1755,-1695,-1630,-1556,-1469,-1377,-1292,-1235,! 4.80
     &-1227,-1283,-1363,-1377,-1290,-1153,-1014, -891, -799, -742,! 4.80
     & -714, -681, -557, -326,  -49,  244,  548,  860, 1181, 1502,! 4.80
     & 1807, 2233, 2473, 2459, 2258, 2009, 1788, 1585, 1398, 1228,! 4.80
     & 1092,  998,  932,  823,  647,  459,  301,  207,  183,  214,! 4.80
     &  260,  281,  248,  159,   65,   -4,  -50/                  ! 4.80

      data ross_default(1:nt_ross_c, 29, 1) /                     ! 5.00
     &-1840,-1790,-1737,-1678,-1615,-1542,-1453,-1355,-1256,-1174,! 5.00
     &-1127,-1137,-1195,-1226,-1164,-1035, -892, -762, -660, -590,! 5.00
     & -551, -519, -421, -213,   49,  334,  628,  930, 1240, 1551,! 5.00
     & 1852, 2284, 2562, 2609, 2448, 2209, 1985, 1785, 1598, 1426,! 5.00
     & 1280, 1174, 1100,  997,  817,  612,  427,  302,  251,  261,! 5.00
     &  295,  309,  274,  181,   77,    2,  -46/                  ! 5.00

      data ross_default(1:nt_ross_c, 30, 1) /                     ! 5.20
     &-1803,-1756,-1707,-1651,-1591,-1520,-1433,-1332,-1226,-1130,! 5.20
     &-1062,-1039,-1061,-1081,-1031, -912, -770, -636, -525, -444,! 5.20
     & -393, -354, -276,  -93,  154,  428,  712, 1002, 1302, 1604,! 5.20
     & 1897, 2332, 2636, 2741, 2631, 2411, 2188, 1990, 1804, 1633,! 5.20
     & 1482, 1366, 1278, 1178,  999,  782,  575,  421,  338,  323,! 5.20
     &  342,  349,  308,  211,   97,   14,  -38/                  ! 5.20

      data ross_default(1:nt_ross_c, 31, 1) /                     ! 5.40
     &-1767,-1723,-1677,-1626,-1568,-1499,-1414,-1312,-1200,-1091,! 5.40
     &-1000, -947, -934, -938, -899, -792, -652, -513, -394, -302,! 5.40
     & -240, -190, -126,   30,  262,  524,  798, 1080, 1368, 1659,! 5.40
     & 1946, 2379, 2703, 2858, 2804, 2610, 2390, 2195, 2012, 1841,! 5.40
     & 1687, 1561, 1462, 1361, 1186,  959,  733,  550,  437,  395,! 5.40
     &  396,  394,  348,  248,  122,   28,  -28/                  ! 5.40

      data ross_default(1:nt_ross_c, 32, 1) /                     ! 5.60
     &-1737,-1698,-1655,-1607,-1552,-1485,-1400,-1297,-1180,-1061,! 5.60
     & -956, -878, -834, -815, -773, -673, -535, -394, -267, -165,! 5.60
     &  -92,  -28,   27,  161,  375,  625,  889, 1160, 1437, 1718,! 5.60
     & 1996, 2426, 2763, 2959, 2963, 2805, 2594, 2400, 2221, 2053,! 5.60
     & 1897, 1763, 1654, 1548, 1378, 1146,  903,  697,  554,  483,! 5.60
     &  462,  449,  399,  294,  157,   49,  -15/                  ! 5.60

      data ross_default(1:nt_ross_c, 33, 1) /                     ! 5.80
     &-1714,-1678,-1639,-1595,-1542,-1476,-1392,-1288,-1167,-1041,! 5.80
     & -924, -829, -761, -714, -657, -558, -422, -277, -145,  -34,! 5.80
     &   50,  129,  185,  298,  492,  729,  983, 1244, 1511, 1781,! 5.80
     & 2050, 2473, 2818, 3046, 3105, 2993, 2799, 2607, 2432, 2267,! 5.80
     & 2111, 1972, 1853, 1738, 1574, 1339, 1085,  859,  688,  587,! 5.80
     &  542,  515,  459,  350,  203,   78,    3/                  ! 5.80

      data ross_default(1:nt_ross_c, 34, 1) /                     ! 6.00
     &-1689,-1657,-1622,-1582,-1532,-1467,-1384,-1278,-1154,-1022,! 6.00
     & -896, -785, -694, -620, -546, -447, -313, -166,  -27,   92,! 6.00
     &  188,  283,  344,  440,  614,  837, 1080, 1331, 1587, 1847,! 6.00
     & 2107, 2522, 2872, 3123, 3233, 3172, 3001, 2813, 2642, 2480,! 6.00
     & 2326, 2182, 2053, 1931, 1771, 1535, 1271, 1028,  831,  700,! 6.00
     &  631,  589,  527,  415,  260,  116,   26/                  ! 6.00

      data ross_default(1:nt_ross_c, 35, 1) /                     ! 6.25
     &-1643,-1618,-1590,-1556,-1512,-1452,-1370,-1264,-1138,-1002,! 6.25
     & -871, -749, -641, -541, -441, -326, -187,  -35,  111,  241,! 6.25
     &  349,  465,  538,  623,  774,  979, 1207, 1445, 1688, 1934,! 6.25
     & 2182, 2584, 2937, 3209, 3367, 3372, 3248, 3075, 2909, 2751,! 6.25
     & 2598, 2452, 2316, 2181, 2020, 1789, 1519, 1263, 1042,  878,! 6.25
     &  773,  706,  633,  517,  353,  187,   74/                  ! 6.25

      data ross_default(1:nt_ross_c, 36, 1) /                     ! 6.50
     &-1594,-1575,-1554,-1527,-1490,-1434,-1354,-1248,-1121, -984,! 6.50
     & -847, -716, -592, -470, -345, -214,  -70,   85,  240,  380,! 6.50
     &  501,  638,  728,  809,  939, 1125, 1339, 1564, 1794, 2027,! 6.50
     & 2262, 2650, 3004, 3289, 3483, 3551, 3481, 3332, 3172, 3019,! 6.50
     & 2870, 2722, 2579, 2434, 2268, 2045, 1771, 1503, 1261, 1067,! 6.50
     &  929,  837,  750,  631,  464,  279,  142/                  ! 6.50

      data ross_default(1:nt_ross_c, 37, 1) /                     ! 6.75
     &-1507,-1496,-1482,-1464,-1435,-1388,-1315,-1215,-1092, -958,! 6.75
     & -823, -689, -556, -418, -273, -124,   31,  194,  355,  506,! 6.75
     &  639,  797,  906,  992, 1109, 1279, 1479, 1692, 1909, 2128,! 6.75
     & 2351, 2723, 3071, 3366, 3584, 3701, 3691, 3582, 3438, 3292,! 6.75
     & 3146, 2999, 2851, 2695, 2519, 2300, 2029, 1755, 1503, 1289,! 6.75
     & 1123, 1000,  894,  769,  598,  401,  235/                  ! 6.75

      data ross_default(1:nt_ross_c, 38, 1) /                     ! 7.00
     &-1416,-1412,-1405,-1395,-1375,-1337,-1272,-1177,-1058, -927,! 7.00
     & -792, -657, -516, -365, -205,  -40,  125,  293,  460,  619,! 7.00
     &  764,  943, 1075, 1173, 1282, 1436, 1624, 1824, 2029, 2236,! 7.00
     & 2447, 2801, 3142, 3442, 3679, 3834, 3881, 3819, 3697, 3561,! 7.00
     & 3420, 3276, 3123, 2956, 2771, 2555, 2291, 2008, 1747, 1516,! 7.00
     & 1324, 1174, 1049,  917,  747,  545,  354/                  ! 7.00

      data ross_default(1:nt_ross_c, 39, 1) /                     ! 7.25
     &-1273,-1274,-1278,-1274,-1261,-1235,-1184,-1104, -999, -877,! 7.25
     & -748, -613, -467, -309, -141,   32,  207,  382,  553,  718,! 7.25
     &  872, 1071, 1224, 1338, 1448, 1592, 1768, 1959, 2155, 2351,! 7.25
     & 2552, 2888, 3217, 3516, 3767, 3950, 4042, 4032, 3946, 3830,! 7.25
     & 3701, 3558, 3401, 3224, 3025, 2805, 2549, 2273, 2009, 1771,! 7.25
     & 1559, 1384, 1234, 1088,  916,  713,  508/                  ! 7.25

      data ross_default(1:nt_ross_c, 40, 1) /                     ! 7.50
     &-1130,-1136,-1149,-1149,-1143,-1125,-1086,-1020, -928, -814,! 7.50
     & -689, -554, -406, -245,  -73,  105,  285,  464,  639,  808,! 7.50
     &  968, 1184, 1359, 1493, 1610, 1747, 1913, 2096, 2283, 2471,! 7.50
     & 2663, 2982, 3299, 3592, 3855, 4059, 4189, 4227, 4181, 4091,! 7.50
     & 3978, 3840, 3679, 3491, 3278, 3053, 2805, 2538, 2274, 2025,! 7.50
     & 1796, 1598, 1426, 1268, 1095,  897,  689/                  ! 7.50

      data ross_default(1:nt_ross_c, 41, 1) /                     ! 7.75
     & -955, -964, -975, -977, -974, -968, -942, -894, -820, -721,! 7.75
     & -605, -471, -324, -165,    3,  179,  360,  540,  716,  886,! 7.75
     & 1050, 1277, 1471, 1626, 1756, 1892, 2053, 2228, 2408, 2588,! 7.75
     & 2773, 3077, 3379, 3673, 3940, 4160, 4318, 4397, 4395, 4335,! 7.75
     & 4238, 4107, 3950, 3755, 3531, 3295, 3050, 2789, 2527, 2285,! 7.75
     & 2055, 1843, 1651, 1474, 1292, 1092,  882/                  ! 7.75

      data ross_default(1:nt_ross_c, 42, 1) /                     ! 8.00
     & -783, -793, -803, -806, -804, -807, -788, -752, -694, -610,! 8.00
     & -504, -376, -232,  -76,   87,  258,  435,  614,  789,  959,! 8.00
     & 1124, 1357, 1566, 1742, 1889, 2031, 2188, 2359, 2533, 2706,! 8.00
     & 2888, 3177, 3466, 3758, 4027, 4261, 4442, 4556, 4594, 4563,! 8.00
     & 4484, 4364, 4213, 4014, 3783, 3534, 3292, 3039, 2781, 2544,! 8.00
     & 2313, 2088, 1879, 1686, 1496, 1296, 1088/                  ! 8.00

      data ross_default(1:nt_ross_c,  1, 2) /                     !-4.00
     &-5084,-4961,-4797,-4621,-4464,-4345,-4270,-4238,-4230,-4217,!-4.00
     &-4167,-4035,-3804,-3503,-3156,-2784,-2403,-2025,-1657,-1305,!-4.00
     & -984, -646, -538, -521, -522, -525, -527, -525, -509, -494,!-4.00
     & -490, -485, -486, -488, -484, -478, -455, -450, -446, -441,!-4.00
     & -434, -422, -408, -387, -354, -306, -239, -154,  -54,   47,!-4.00
     &  127,  162,  146,   95,   32,  -23,  -63/                  !-4.00

      data ross_default(1:nt_ross_c,  2, 2) /                     !-3.50
     &-5090,-5016,-4873,-4707,-4538,-4396,-4294,-4236,-4217,-4211,!-3.50
     &-4188,-4108,-3932,-3668,-3349,-2998,-2631,-2261,-1897,-1544,!-3.50
     &-1209, -786, -572, -523, -518, -521, -524, -525, -517, -498,!-3.50
     & -490, -483, -483, -486, -483, -478, -458, -449, -445, -440,!-3.50
     & -434, -422, -407, -386, -353, -305, -239, -154,  -54,   47,!-3.50
     &  127,  162,  146,   95,   32,  -23,  -63/                  !-3.50

      data ross_default(1:nt_ross_c,  3, 2) /                     !-3.00
     &-5059,-5041,-4936,-4786,-4620,-4461,-4334,-4248,-4206,-4197,!-3.00
     &-4189,-4148,-4030,-3814,-3528,-3200,-2850,-2491,-2133,-1783,!-3.00
     &-1445, -981, -654, -536, -515, -516, -520, -523, -521, -505,!-3.00
     & -491, -482, -478, -483, -482, -477, -463, -447, -444, -438,!-3.00
     & -433, -421, -405, -385, -353, -305, -239, -154,  -54,   47,!-3.00
     &  127,  162,  146,   95,   32,  -23,  -63/                  !-3.00

      data ross_default(1:nt_ross_c,  4, 2) /                     !-2.50
     &-4944,-5023,-4978,-4853,-4701,-4537,-4389,-4276,-4206,-4180,!-2.50
     &-4176,-4160,-4094,-3936,-3689,-3388,-3058,-2713,-2364,-2019,!-2.50
     &-1682,-1204, -800, -577, -516, -509, -513, -518, -520, -512,!-2.50
     & -494, -481, -473, -478, -480, -475, -466, -446, -442, -437,!-2.50
     & -431, -420, -404, -383, -352, -305, -239, -153,  -54,   47,!-2.50
     &  127,  162,  146,   95,   32,  -23,  -63/                  !-2.50

      data ross_default(1:nt_ross_c,  5, 2) /                     !-2.00
     &-4642,-4920,-4978,-4903,-4770,-4616,-4457,-4320,-4222,-4168,!-2.00
     &-4155,-4151,-4123,-4024,-3829,-3561,-3254,-2925,-2588,-2249,!-2.00
     &-1916,-1435, -995, -668, -531, -501, -502, -509, -514, -513,!-2.00
     & -499, -479, -469, -470, -476, -473, -466, -447, -440, -435,!-2.00
     & -429, -419, -403, -381, -351, -304, -238, -153,  -53,   47,!-2.00
     &  127,  162,  146,   95,   32,  -23,  -63/                  !-2.00

      data ross_default(1:nt_ross_c,  6, 2) /                     !-1.50
     &-4083,-4631,-4887,-4918,-4823,-4687,-4531,-4377,-4253,-4168,!-1.50
     &-4131,-4127,-4121,-4073,-3938,-3714,-3434,-3125,-2801,-2473,!-1.50
     &-2145,-1665,-1211, -817, -574, -496, -486, -493, -502, -508,!-1.50
     & -502, -478, -466, -461, -469, -469, -463, -448, -437, -432,!-1.50
     & -426, -418, -401, -380, -349, -303, -238, -152,  -53,   47,!-1.50
     &  127,  162,  146,   95,   32,  -23,  -63/                  !-1.50

      data ross_default(1:nt_ross_c,  7, 2) /                     !-1.00
     &-3375,-4080,-4606,-4840,-4844,-4738,-4598,-4440,-4294,-4182,!-1.00
     &-4113,-4091,-4094,-4080,-4006,-3838,-3594,-3308,-3001,-2685,!-1.00
     &-2365,-1890,-1429,-1000, -664, -498, -459, -464, -478, -491,!-1.00
     & -496, -476, -461, -451, -457, -463, -458, -448, -433, -429,!-1.00
     & -423, -415, -400, -378, -347, -302, -237, -152,  -52,   48,!-1.00
     &  127,  162,  146,   95,   32,  -23,  -63/                  !-1.00

      data ross_default(1:nt_ross_c,  8, 2) /                     !-0.50
     &-2712,-3375,-4054,-4558,-4774,-4754,-4641,-4495,-4337,-4199,!-0.50
     &-4100,-4049,-4043,-4048,-4022,-3919,-3724,-3468,-3182,-2880,!-0.50
     &-2570,-2103,-1640,-1194, -796, -522, -418, -409, -429, -453,!-0.50
     & -470, -469, -453, -440, -441, -451, -451, -443, -428, -424,!-0.50
     & -418, -411, -398, -376, -345, -301, -237, -151,  -51,   48,!-0.50
     &  127,  162,  146,   95,   32,  -23,  -63/                  !-0.50

      data ross_default(1:nt_ross_c,  9, 2) /                     ! 0.00
     &-2261,-2709,-3346,-3998,-4485,-4678,-4641,-4519,-4364,-4207,! 0.00
     &-4078,-3995,-3964,-3972,-3978,-3935,-3803,-3589,-3328,-3043,! 0.00
     &-2747,-2292,-1831,-1374, -940, -577, -370, -317, -334, -371,! 0.00
     & -407, -440, -434, -426, -420, -432, -437, -433, -422, -416,! 0.00
     & -412, -406, -395, -374, -343, -298, -236, -151,  -50,   50,! 0.00
     &  128,  162,  146,   95,   32,  -23,  -63/                  ! 0.00

      data ross_default(1:nt_ross_c, 10, 2) /                     ! 0.50
     &-2078,-2234,-2681,-3284,-3909,-4372,-4540,-4488,-4351,-4186,! 0.50
     &-4030,-3914,-3848,-3838,-3857,-3860,-3797,-3639,-3412,-3150,! 0.50
     &-2871,-2434,-1981,-1521,-1066, -646, -330, -187, -178, -221,! 0.50
     & -279, -360, -387, -394, -391, -403, -414, -414, -408, -402,! 0.50
     & -402, -398, -389, -370, -340, -296, -234, -150,  -49,   52,! 0.50
     &  129,  163,  146,   95,   32,  -23,  -63/                  ! 0.50

      data ross_default(1:nt_ross_c, 11, 2) /                     ! 1.00
     &-2023,-2024,-2195,-2621,-3191,-3777,-4203,-4343,-4271,-4118,! 1.00
     &-3946,-3795,-3690,-3642,-3648,-3674,-3669,-3580,-3400,-3166,! 1.00
     &-2906,-2493,-2058,-1606,-1145, -695, -302,  -42,   40,   11,! 1.00
     &  -61, -195, -282, -322, -340, -356, -378, -382, -380, -378,! 1.00
     & -384, -385, -380, -365, -336, -292, -231, -149,  -48,   54,! 1.00
     &  130,  163,  146,   95,   32,  -23,  -63/                  ! 1.00

      data ross_default(1:nt_ross_c, 12, 2) /                     ! 1.25
     &-2013,-1991,-2079,-2372,-2854,-3419,-3919,-4183,-4186,-4056,! 1.25
     &-3884,-3720,-3596,-3527,-3516,-3540,-3554,-3500,-3350,-3132,! 1.25
     &-2883,-2482,-2060,-1618,-1161, -705, -287,   24,  163,  157,! 1.25
     &   84,  -72, -196, -261, -298, -322, -351, -360, -359, -360,! 1.25
     & -369, -375, -372, -361, -333, -290, -229, -147,  -48,   55,! 1.25
     &  132,  164,  146,   95,   32,  -23,  -63/                  ! 1.25

      data ross_default(1:nt_ross_c, 13, 2) /                     ! 1.50
     &-2005,-1957,-1968,-2138,-2535,-3060,-3593,-3971,-4073,-3978,! 1.50
     &-3809,-3633,-3490,-3398,-3366,-3383,-3409,-3386,-3269,-3072,! 1.50
     &-2834,-2446,-2036,-1606,-1158, -703, -269,   86,  286,  318,! 1.50
     &  253,   76,  -84, -179, -239, -274, -316, -334, -334, -335,! 1.50
     & -349, -361, -363, -355, -330, -288, -227, -146,  -47,   56,! 1.50
     &  134,  165,  147,   95,   32,  -23,  -63/                  ! 1.50

      data ross_default(1:nt_ross_c, 14, 2) /                     ! 1.75
     &-2001,-1946,-1929,-2019,-2292,-2730,-3238,-3681,-3893,-3863,! 1.75
     &-3714,-3535,-3377,-3264,-3210,-3211,-3237,-3238,-3157,-2985,! 1.75
     &-2760,-2385,-1989,-1572,-1136, -687, -245,  140,  398,  482,! 1.75
     &  436,  252,   57,  -72, -159, -214, -268, -299, -303, -304,! 1.75
     & -320, -341, -349, -346, -324, -285, -225, -144,  -46,   57,! 1.75
     &  136,  166,  147,   95,   32,  -23,  -63/                  ! 1.75

      data ross_default(1:nt_ross_c, 15, 2) /                     ! 2.00
     &-1997,-1935,-1892,-1905,-2064,-2417,-2885,-3357,-3672,-3725,! 2.00
     &-3604,-3426,-3254,-3122,-3045,-3026,-3047,-3064,-3016,-2874,! 2.00
     &-2667,-2306,-1921,-1519,-1097, -658, -216,  189,  497,  641,! 2.00
     &  629,  449,  226,   58,  -58, -135, -203, -253, -265, -265,! 2.00
     & -282, -313, -330, -334, -318, -280, -222, -142,  -44,   58,! 2.00
     &  138,  167,  148,   95,   32,  -23,  -63/                  ! 2.00

      data ross_default(1:nt_ross_c, 16, 2) /                     ! 2.25
     &-1994,-1930,-1878,-1863,-1946,-2186,-2568,-3012,-3385,-3533,! 2.25
     &-3466,-3303,-3126,-2978,-2880,-2840,-2846,-2868,-2849,-2741,! 2.25
     &-2555,-2211,-1839,-1450,-1043, -616, -180,  235,  579,  782,! 2.25
     &  819,  659,  419,  214,   68,  -37, -122, -191, -217, -220,! 2.25
     & -234, -273, -302, -315, -307, -274, -217, -139,  -42,   60,! 2.25
     &  141,  170,  149,   96,   32,  -23,  -63/                  ! 2.25

      data ross_default(1:nt_ross_c, 17, 2) /                     ! 2.50
     &-1992,-1925,-1864,-1822,-1833,-1967,-2267,-2669,-3072,-3313,! 2.50
     &-3314,-3172,-2993,-2831,-2714,-2651,-2640,-2659,-2662,-2589,! 2.50
     &-2429,-2105,-1744,-1368, -975, -563, -137,  281,  649,  905,! 2.50
     &  999,  878,  630,  393,  217,   82,  -20, -112, -158, -166,! 2.50
     & -176, -220, -264, -289, -292, -265, -212, -135,  -40,   62,! 2.50
     &  144,  173,  150,   96,   33,  -23,  -63/                  ! 2.50

      data ross_default(1:nt_ross_c, 18, 2) /                     ! 2.75
     &-1988,-1920,-1857,-1806,-1789,-1854,-2051,-2369,-2744,-3040,! 2.75
     &-3121,-3022,-2853,-2685,-2551,-2468,-2437,-2445,-2457,-2416,! 2.75
     &-2287,-1988,-1641,-1276, -898, -501,  -87,  328,  709, 1004,! 2.75
     & 1157, 1096,  853,  594,  391,  226,   99,  -11,  -80, -100,! 2.75
     & -109, -151, -209, -251, -267, -250, -203, -129,  -35,   64,! 2.75
     &  147,  177,  152,   97,   33,  -23,  -63/                  ! 2.75

      data ross_default(1:nt_ross_c, 19, 2) /                     ! 3.00
     &-1984,-1916,-1850,-1790,-1746,-1746,-1848,-2084,-2417,-2746,! 3.00
     &-2909,-2865,-2712,-2539,-2391,-2288,-2236,-2229,-2243,-2228,! 3.00
     &-2133,-1864,-1531,-1178, -812, -429,  -29,  377,  764, 1087,! 3.00
     & 1292, 1307, 1083,  809,  581,  392,  242,  110,   16,  -21,! 3.00
     &  -31,  -68, -138, -198, -233, -230, -192, -122,  -30,   68,! 3.00
     &  151,  182,  154,   98,   33,  -22,  -62/                  ! 3.00

      data ross_default(1:nt_ross_c, 20, 2) /                     ! 3.20
     &-1977,-1910,-1844,-1782,-1730,-1708,-1761,-1925,-2192,-2501,! 3.20
     &-2709,-2717,-2589,-2421,-2266,-2150,-2083,-2061,-2069,-2066,! 3.20
     &-1998,-1757,-1438,-1094, -738, -367,   20,  419,  806, 1143,! 3.20
     & 1381, 1466, 1268,  992,  747,  543,  384,  231,  112,   57,! 3.20
     &   39,    8,  -67, -141, -193, -206, -177, -113,  -24,   72,! 3.20
     &  154,  187,  158,  100,   34,  -22,  -62/                  ! 3.20

      data ross_default(1:nt_ross_c, 21, 2) /                     ! 3.40
     &-1971,-1904,-1838,-1773,-1714,-1672,-1679,-1774,-1976,-2255,! 3.40
     &-2496,-2561,-2465,-2304,-2144,-2015,-1932,-1896,-1895,-1899,! 3.40
     &-1854,-1646,-1343,-1008, -661, -301,   75,  463,  847, 1193,! 3.40
     & 1458, 1613, 1452, 1179,  919,  704,  545,  369,  223,  148,! 3.40
     &  120,   94,   16,  -71, -142, -173, -158, -101,  -16,   78,! 3.40
     &  158,  193,  162,  101,   35,  -22,  -62/                  ! 3.40

      data ross_default(1:nt_ross_c, 22, 2) /                     ! 3.60
     &-1961,-1895,-1829,-1764,-1700,-1644,-1619,-1659,-1799,-2029,! 3.60
     &-2275,-2390,-2331,-2183,-2021,-1884,-1787,-1736,-1724,-1728,! 3.60
     &-1702,-1529,-1244, -919, -581, -231,  133,  511,  889, 1239,! 3.60
     & 1524, 1745, 1632, 1369, 1100,  875,  705,  524,  351,  255,! 3.60
     &  214,  188,  113,   12,  -77, -129, -131,  -85,   -6,   85,! 3.60
     &  164,  200,  168,  104,   36,  -21,  -61/                  ! 3.60

      data ross_default(1:nt_ross_c, 23, 2) /                     ! 3.80
     &-1947,-1883,-1819,-1754,-1688,-1624,-1579,-1580,-1659,-1828,! 3.80
     &-2051,-2202,-2188,-2060,-1901,-1757,-1648,-1583,-1557,-1556,! 3.80
     &-1543,-1405,-1141, -827, -498, -158,  195,  562,  932, 1283,! 3.80
     & 1580, 1860, 1805, 1561, 1287, 1054,  857,  692,  496,  380,! 3.80
     &  322,  292,  223,  112,    3,  -72,  -94,  -63,    7,   95,! 3.80
     &  171,  207,  175,  108,   38,  -20,  -61/                  ! 3.80

      data ross_default(1:nt_ross_c, 24, 2) /                     ! 4.00
     &-1934,-1872,-1808,-1743,-1676,-1606,-1542,-1505,-1526,-1635,! 4.00
     &-1827,-2005,-2039,-1936,-1782,-1632,-1512,-1433,-1394,-1385,! 4.00
     &-1379,-1276,-1034, -733, -413,  -82,  260,  616,  977, 1325,! 4.00
     & 1631, 1960, 1968, 1751, 1477, 1235, 1020,  870,  654,  520,! 4.00
     &  444,  407,  345,  225,   99,   -1,  -46,  -34,   25,  108,! 4.00
     &  181,  216,  184,  112,   40,  -19,  -60/                  ! 4.00

      data ross_default(1:nt_ross_c, 25, 2) /                     ! 4.20
     &-1918,-1857,-1794,-1730,-1663,-1590,-1519,-1463,-1451,-1508,! 4.20
     &-1644,-1807,-1874,-1802,-1659,-1509,-1385,-1292,-1239,-1219,! 4.20
     &-1211,-1136, -922, -635, -325,   -3,  328,  673, 1025, 1368,! 4.20
     & 1678, 2044, 2118, 1939, 1673, 1425, 1208, 1031,  829,  681,! 4.20
     &  586,  535,  479,  356,  214,   89,   17,    7,   51,  126,! 4.20
     &  194,  227,  196,  120,   44,  -16,  -58/                  ! 4.20

      data ross_default(1:nt_ross_c, 26, 2) /                     ! 4.40
     &-1901,-1843,-1780,-1717,-1650,-1576,-1497,-1425,-1380,-1388,! 4.40
     &-1469,-1608,-1701,-1665,-1537,-1389,-1260,-1155,-1087,-1055,! 4.40
     &-1043, -989, -805, -535, -234,   77,  400,  733, 1075, 1412,! 4.40
     & 1722, 2116, 2254, 2122, 1869, 1616, 1398, 1202, 1010,  852,! 4.40
     &  741,  676,  622,  500,  343,  195,   94,   59,   85,  148,! 4.40
     &  211,  241,  211,  129,   49,  -14,  -57/                  ! 4.40

      data ross_default(1:nt_ross_c, 27, 2) /                     ! 4.60
     &-1881,-1826,-1765,-1703,-1637,-1562,-1479,-1395,-1326,-1296,! 4.60
     &-1330,-1431,-1529,-1522,-1414,-1269,-1135,-1020, -940, -895,! 4.60
     & -876, -836, -682, -430, -141,  161,  474,  796, 1127, 1457,! 4.60
     & 1765, 2179, 2372, 2296, 2065, 1811, 1592, 1388, 1202, 1035,! 4.60
     &  910,  832,  774,  657,  489,  319,  189,  126,  129,  178,! 4.60
     &  234,  259,  228,  142,   56,  -10,  -54/                  ! 4.60

      data ross_default(1:nt_ross_c, 28, 2) /                     ! 4.80
     &-1859,-1806,-1749,-1689,-1624,-1551,-1464,-1372,-1288,-1232,! 4.80
     &-1224,-1279,-1360,-1374,-1288,-1150,-1010, -888, -796, -739,! 4.80
     & -710, -677, -552, -321,  -44,  248,  551,  863, 1183, 1504,! 4.80
     & 1809, 2234, 2474, 2460, 2260, 2011, 1789, 1587, 1399, 1229,! 4.80
     & 1093, 1000,  934,  825,  649,  460,  302,  209,  185,  216,! 4.80
     &  263,  283,  250,  160,   66,   -4,  -50/                  ! 4.80

      data ross_default(1:nt_ross_c, 29, 2) /                     ! 5.00
     &-1837,-1787,-1734,-1675,-1613,-1540,-1451,-1352,-1254,-1172,! 5.00
     &-1125,-1135,-1193,-1224,-1162,-1033, -889, -760, -657, -587,! 5.00
     & -548, -515, -417, -209,   54,  337,  631,  932, 1242, 1553,! 5.00
     & 1853, 2286, 2563, 2610, 2449, 2210, 1986, 1786, 1599, 1427,! 5.00
     & 1281, 1175, 1101,  999,  818,  613,  428,  304,  253,  263,! 5.00
     &  298,  312,  276,  182,   78,    2,  -45/                  ! 5.00

      data ross_default(1:nt_ross_c, 30, 2) /                     ! 5.20
     &-1801,-1754,-1705,-1650,-1590,-1519,-1431,-1331,-1225,-1129,! 5.20
     &-1060,-1038,-1060,-1080,-1030, -911, -768, -634, -523, -441,! 5.20
     & -391, -351, -272,  -89,  158,  431,  715, 1006, 1304, 1606,! 5.20
     & 1899, 2333, 2637, 2742, 2632, 2411, 2188, 1991, 1805, 1634,! 5.20
     & 1483, 1367, 1279, 1179, 1000,  783,  576,  422,  340,  325,! 5.20
     &  344,  351,  309,  213,   98,   14,  -37/                  ! 5.20

      data ross_default(1:nt_ross_c, 31, 2) /                     ! 5.40
     &-1766,-1723,-1676,-1625,-1567,-1498,-1413,-1311,-1199,-1090,! 5.40
     &-1000, -946, -933, -937, -897, -790, -650, -512, -393, -300,! 5.40
     & -238, -187, -123,   34,  265,  527,  801, 1082, 1370, 1661,! 5.40
     & 1947, 2380, 2704, 2859, 2804, 2611, 2390, 2195, 2013, 1842,! 5.40
     & 1688, 1562, 1463, 1362, 1187,  961,  734,  552,  439,  397,! 5.40
     &  398,  396,  350,  249,  123,   29,  -28/                  ! 5.40

      data ross_default(1:nt_ross_c, 32, 2) /                     ! 5.60
     &-1737,-1697,-1655,-1607,-1552,-1484,-1400,-1297,-1180,-1061,! 5.60
     & -956, -877, -834, -814, -772, -672, -534, -393, -266, -164,! 5.60
     &  -90,  -26,   29,  164,  378,  627,  891, 1162, 1439, 1720,! 5.60
     & 1997, 2427, 2763, 2959, 2963, 2805, 2594, 2401, 2222, 2053,! 5.60
     & 1897, 1764, 1655, 1549, 1379, 1146,  905,  698,  556,  484,! 5.60
     &  464,  452,  400,  295,  158,   50,  -14/                  ! 5.60

      data ross_default(1:nt_ross_c, 33, 2) /                     ! 5.80
     &-1714,-1678,-1639,-1595,-1542,-1476,-1392,-1288,-1167,-1041,! 5.80
     & -924, -829, -761, -714, -657, -558, -421, -277, -144,  -33,! 5.80
     &   51,  130,  187,  300,  495,  732,  985, 1246, 1512, 1782,! 5.80
     & 2051, 2474, 2819, 3046, 3105, 2994, 2799, 2607, 2433, 2267,! 5.80
     & 2112, 1972, 1853, 1739, 1575, 1339, 1086,  860,  690,  588,! 5.80
     &  544,  517,  461,  351,  204,   79,    3/                  ! 5.80

      data ross_default(1:nt_ross_c, 34, 2) /                     ! 6.00
     &-1689,-1657,-1622,-1582,-1532,-1467,-1384,-1278,-1154,-1022,! 6.00
     & -896, -785, -694, -620, -546, -447, -313, -165,  -27,   92,! 6.00
     &  188,  284,  345,  441,  615,  839, 1081, 1332, 1589, 1848,! 6.00
     & 2108, 2523, 2872, 3124, 3233, 3172, 3002, 2813, 2642, 2481,! 6.00
     & 2326, 2182, 2054, 1931, 1771, 1535, 1272, 1029,  832,  702,! 6.00
     &  632,  591,  529,  417,  261,  116,   26/                  ! 6.00

      data ross_default(1:nt_ross_c, 35, 2) /                     ! 6.25
     &-1643,-1618,-1590,-1556,-1512,-1452,-1370,-1264,-1138,-1002,! 6.25
     & -871, -749, -640, -541, -441, -326, -187,  -35,  111,  241,! 6.25
     &  350,  466,  539,  623,  775,  980, 1209, 1446, 1689, 1935,! 6.25
     & 2183, 2585, 2938, 3209, 3367, 3372, 3248, 3075, 2909, 2751,! 6.25
     & 2598, 2452, 2316, 2182, 2020, 1789, 1520, 1264, 1043,  879,! 6.25
     &  775,  708,  635,  518,  354,  187,   74/                  ! 6.25

      data ross_default(1:nt_ross_c, 36, 2) /                     ! 6.50
     &-1593,-1575,-1554,-1527,-1490,-1434,-1354,-1248,-1121, -984,! 6.50
     & -847, -716, -592, -470, -345, -214,  -69,   85,  240,  380,! 6.50
     &  501,  638,  728,  809,  940, 1126, 1340, 1565, 1795, 2028,! 6.50
     & 2263, 2651, 3004, 3289, 3483, 3551, 3481, 3332, 3172, 3020,! 6.50
     & 2870, 2723, 2579, 2434, 2268, 2045, 1771, 1503, 1262, 1068,! 6.50
     &  930,  838,  752,  632,  465,  280,  142/                  ! 6.50

      data ross_default(1:nt_ross_c, 37, 2) /                     ! 6.75
     &-1507,-1496,-1482,-1464,-1435,-1388,-1315,-1215,-1092, -958,! 6.75
     & -823, -689, -556, -418, -273, -124,   31,  194,  355,  506,! 6.75
     &  639,  797,  906,  992, 1110, 1279, 1480, 1692, 1909, 2129,! 6.75
     & 2352, 2723, 3072, 3366, 3584, 3701, 3691, 3582, 3438, 3292,! 6.75
     & 3146, 2999, 2851, 2695, 2519, 2300, 2029, 1755, 1504, 1290,! 6.75
     & 1124, 1000,  895,  769,  599,  402,  236/                  ! 6.75

      data ross_default(1:nt_ross_c, 38, 2) /                     ! 7.00
     &-1416,-1412,-1405,-1395,-1375,-1337,-1272,-1177,-1058, -927,! 7.00
     & -792, -657, -516, -365, -205,  -40,  125,  293,  460,  619,! 7.00
     &  764,  943, 1075, 1173, 1282, 1436, 1624, 1824, 2029, 2236,! 7.00
     & 2447, 2801, 3142, 3442, 3679, 3834, 3881, 3819, 3697, 3561,! 7.00
     & 3420, 3276, 3123, 2956, 2771, 2555, 2291, 2009, 1748, 1517,! 7.00
     & 1324, 1174, 1050,  917,  747,  545,  355/                  ! 7.00

      data ross_default(1:nt_ross_c, 39, 2) /                     ! 7.25
     &-1273,-1274,-1278,-1274,-1261,-1235,-1184,-1104, -999, -877,! 7.25
     & -748, -613, -467, -309, -141,   32,  207,  382,  553,  718,! 7.25
     &  872, 1071, 1224, 1338, 1448, 1592, 1768, 1959, 2155, 2351,! 7.25
     & 2552, 2888, 3217, 3516, 3767, 3950, 4042, 4032, 3946, 3830,! 7.25
     & 3701, 3558, 3401, 3224, 3025, 2805, 2549, 2273, 2011, 1771,! 7.25
     & 1560, 1384, 1235, 1089,  916,  713,  509/                  ! 7.25

      data ross_default(1:nt_ross_c, 40, 2) /                     ! 7.50
     &-1130,-1136,-1149,-1149,-1143,-1125,-1086,-1020, -928, -814,! 7.50
     & -689, -554, -406, -245,  -73,  105,  285,  464,  639,  808,! 7.50
     &  968, 1184, 1359, 1493, 1610, 1747, 1913, 2096, 2283, 2471,! 7.50
     & 2663, 2982, 3299, 3592, 3855, 4059, 4189, 4227, 4181, 4091,! 7.50
     & 3978, 3840, 3679, 3491, 3278, 3053, 2805, 2538, 2274, 2025,! 7.50
     & 1796, 1598, 1427, 1268, 1095,  897,  689/                  ! 7.50

      data ross_default(1:nt_ross_c, 41, 2) /                     ! 7.75
     & -955, -964, -975, -977, -974, -968, -942, -894, -820, -721,! 7.75
     & -605, -471, -324, -165,    3,  179,  360,  540,  716,  886,! 7.75
     & 1050, 1277, 1471, 1626, 1756, 1892, 2053, 2228, 2409, 2588,! 7.75
     & 2773, 3077, 3379, 3673, 3940, 4160, 4318, 4397, 4395, 4335,! 7.75
     & 4238, 4107, 3950, 3755, 3531, 3295, 3050, 2789, 2527, 2285,! 7.75
     & 2055, 1843, 1652, 1475, 1292, 1093,  882/                  ! 7.75

      data ross_default(1:nt_ross_c, 42, 2) /                     ! 8.00
     & -783, -793, -803, -806, -804, -807, -788, -752, -694, -610,! 8.00
     & -504, -376, -232,  -76,   87,  258,  435,  614,  789,  959,! 8.00
     & 1124, 1357, 1566, 1742, 1889, 2031, 2188, 2359, 2533, 2706,! 8.00
     & 2888, 3177, 3466, 3758, 4027, 4261, 4442, 4556, 4594, 4563,! 8.00
     & 4484, 4364, 4213, 4014, 3783, 3534, 3292, 3039, 2781, 2544,! 8.00
     & 2314, 2088, 1879, 1686, 1496, 1297, 1088/                  ! 8.00

      data ross_default(1:nt_ross_c,  1, 3) /                     !-4.00
     &-5048,-4934,-4778,-4606,-4450,-4332,-4256,-4226,-4222,-4213,!-4.00
     &-4165,-4034,-3803,-3501,-3155,-2783,-2402,-2024,-1656,-1304,!-4.00
     & -982, -644, -536, -519, -520, -524, -526, -524, -508, -494,!-4.00
     & -489, -483, -485, -487, -484, -478, -454, -449, -446, -441,!-4.00
     & -433, -421, -406, -385, -350, -302, -234, -148,  -47,   54,!-4.00
     &  134,  169,  151,   99,   35,  -21,  -61/                  !-4.00

      data ross_default(1:nt_ross_c,  2, 3) /                     !-3.50
     &-5049,-4983,-4850,-4690,-4523,-4382,-4279,-4221,-4206,-4205,!-3.50
     &-4185,-4106,-3930,-3666,-3348,-2997,-2629,-2259,-1895,-1542,!-3.50
     &-1207, -784, -570, -521, -516, -519, -523, -524, -516, -497,!-3.50
     & -489, -482, -481, -485, -483, -478, -458, -448, -445, -439,!-3.50
     & -433, -420, -405, -384, -350, -301, -234, -148,  -47,   54,!-3.50
     &  134,  169,  151,   99,   35,  -21,  -61/                  !-3.50

      data ross_default(1:nt_ross_c,  3, 3) /                     !-3.00
     &-5014,-5003,-4907,-4766,-4604,-4445,-4318,-4231,-4192,-4187,!-3.00
     &-4183,-4146,-4029,-3813,-3526,-3198,-2848,-2489,-2131,-1781,!-3.00
     &-1443, -979, -652, -534, -512, -513, -518, -521, -520, -504,!-3.00
     & -490, -480, -476, -482, -481, -476, -463, -447, -443, -438,!-3.00
     & -432, -420, -403, -382, -350, -301, -234, -148,  -47,   54,!-3.00
     &  134,  169,  151,   99,   35,  -21,  -61/                  !-3.00

      data ross_default(1:nt_ross_c,  4, 3) /                     !-2.50
     &-4889,-4980,-4943,-4828,-4682,-4520,-4372,-4259,-4188,-4166,!-2.50
     &-4167,-4156,-4091,-3934,-3687,-3386,-3056,-2711,-2362,-2016,!-2.50
     &-1679,-1201, -797, -574, -513, -505, -510, -515, -518, -511,!-2.50
     & -492, -479, -471, -476, -479, -474, -466, -446, -441, -436,!-2.50
     & -430, -419, -402, -381, -349, -301, -234, -147,  -47,   54,!-2.50
     &  134,  169,  151,   99,   35,  -21,  -61/                  !-2.50

      data ross_default(1:nt_ross_c,  5, 3) /                     !-2.00
     &-4569,-4868,-4937,-4872,-4748,-4597,-4439,-4301,-4201,-4149,!-2.00
     &-4141,-4143,-4118,-4022,-3827,-3559,-3251,-2922,-2585,-2246,!-2.00
     &-1913,-1432, -992, -665, -527, -497, -498, -506, -512, -512,!-2.00
     & -497, -477, -467, -468, -475, -472, -465, -446, -439, -434,!-2.00
     & -428, -418, -401, -379, -348, -300, -233, -147,  -47,   55,!-2.00
     &  134,  169,  151,   99,   35,  -21,  -61/                  !-2.00

      data ross_default(1:nt_ross_c,  6, 3) /                     !-1.50
     &-3999,-4563,-4838,-4880,-4794,-4665,-4511,-4357,-4230,-4146,!-1.50
     &-4112,-4115,-4113,-4069,-3936,-3711,-3431,-3122,-2798,-2469,!-1.50
     &-2142,-1662,-1207, -813, -570, -491, -481, -489, -499, -505,!-1.50
     & -500, -476, -463, -458, -467, -468, -462, -447, -436, -432,!-1.50
     & -425, -417, -400, -377, -346, -299, -233, -146,  -46,   55,!-1.50
     &  134,  169,  151,   99,   35,  -21,  -61/                  !-1.50

      data ross_default(1:nt_ross_c,  7, 3) /                     !-1.00
     &-3294,-4001,-4542,-4793,-4809,-4711,-4576,-4418,-4270,-4156,!-1.00
     &-4088,-4073,-4082,-4073,-4002,-3835,-3591,-3305,-2998,-2681,!-1.00
     &-2361,-1886,-1425, -998, -660, -493, -454, -459, -474, -487,!-1.00
     & -492, -473, -458, -447, -455, -462, -457, -447, -432, -428,!-1.00
     & -422, -414, -398, -375, -344, -298, -232, -146,  -45,   55,!-1.00
     &  134,  169,  151,   99,   35,  -21,  -61/                  !-1.00

      data ross_default(1:nt_ross_c,  8, 3) /                     !-0.50
     &-2641,-3298,-3980,-4498,-4730,-4721,-4615,-4471,-4312,-4171,!-0.50
     &-4070,-4022,-4024,-4035,-4014,-3915,-3720,-3464,-3177,-2875,!-0.50
     &-2565,-2098,-1636,-1190, -792, -517, -413, -403, -423, -447,!-0.50
     & -466, -465, -449, -436, -437, -449, -449, -441, -427, -423,!-0.50
     & -417, -410, -396, -373, -342, -297, -232, -145,  -44,   56,!-0.50
     &  135,  169,  151,   99,   35,  -21,  -61/                  !-0.50

      data ross_default(1:nt_ross_c,  9, 3) /                     ! 0.00
     &-2196,-2642,-3275,-3929,-4428,-4636,-4609,-4492,-4337,-4177,! 0.00
     &-4046,-3963,-3937,-3953,-3966,-3928,-3798,-3584,-3322,-3038,! 0.00
     &-2741,-2286,-1826,-1370, -936, -573, -365, -311, -327, -365,! 0.00
     & -402, -435, -430, -420, -415, -429, -435, -430, -420, -414,! 0.00
     & -411, -404, -393, -371, -339, -294, -231, -145,  -43,   57,! 0.00
     &  135,  169,  151,   99,   35,  -21,  -61/                  ! 0.00

      data ross_default(1:nt_ross_c, 10, 3) /                     ! 0.50
     &-2016,-2174,-2619,-3218,-3846,-4319,-4500,-4456,-4322,-4155,! 0.50
     &-3998,-3879,-3815,-3811,-3838,-3848,-3789,-3633,-3406,-3144,! 0.50
     &-2864,-2427,-1975,-1515,-1061, -642, -326, -182, -171, -214,! 0.50
     & -272, -354, -382, -388, -385, -399, -411, -411, -405, -400,! 0.50
     & -401, -396, -388, -368, -336, -292, -229, -144,  -42,   59,! 0.50
     &  136,  169,  151,   99,   35,  -21,  -61/                  ! 0.50

      data ross_default(1:nt_ross_c, 11, 3) /                     ! 1.00
     &-1962,-1968,-2140,-2564,-3133,-3721,-4155,-4305,-4239,-4086,! 1.00
     &-3913,-3760,-3655,-3610,-3623,-3657,-3658,-3572,-3393,-3158,! 1.00
     &-2898,-2484,-2050,-1599,-1139, -691, -297,  -37,   46,   18,! 1.00
     &  -53, -187, -276, -316, -333, -350, -374, -379, -376, -375,! 1.00
     & -383, -383, -378, -363, -333, -288, -226, -143,  -41,   62,! 1.00
     &  138,  170,  152,   99,   35,  -21,  -61/                  ! 1.00

      data ross_default(1:nt_ross_c, 12, 3) /                     ! 1.25
     &-1954,-1935,-2025,-2318,-2799,-3365,-3868,-4141,-4152,-4024,! 1.25
     &-3851,-3686,-3561,-3494,-3489,-3521,-3541,-3491,-3342,-3124,! 1.25
     &-2874,-2473,-2051,-1610,-1154, -700, -283,   29,  169,  163,! 1.25
     &   92,  -64, -189, -254, -290, -315, -347, -357, -356, -357,! 1.25
     & -367, -373, -370, -358, -330, -286, -224, -142,  -41,   63,! 1.25
     &  140,  171,  152,   99,   35,  -21,  -61/                  ! 1.25

      data ross_default(1:nt_ross_c, 13, 3) /                     ! 1.50
     &-1945,-1903,-1916,-2088,-2484,-3009,-3544,-3928,-4037,-3946,! 1.50
     &-3777,-3600,-3456,-3365,-3338,-3361,-3393,-3375,-3260,-3063,! 1.50
     &-2824,-2436,-2027,-1598,-1151, -697, -264,   90,  291,  324,! 1.50
     &  260,   85,  -76, -171, -231, -266, -310, -330, -330, -331,! 1.50
     & -346, -359, -360, -352, -326, -284, -222, -140,  -40,   64,! 1.50
     &  141,  171,  152,   99,   35,  -21,  -61/                  ! 1.50

      data ross_default(1:nt_ross_c, 14, 3) /                     ! 1.75
     &-1942,-1892,-1879,-1970,-2244,-2683,-3193,-3637,-3855,-3831,! 1.75
     &-3683,-3504,-3344,-3233,-3182,-3188,-3220,-3226,-3147,-2975,! 1.75
     &-2750,-2375,-1979,-1564,-1129, -681, -240,  144,  403,  488,! 1.75
     &  444,  261,   66,  -64, -150, -205, -261, -294, -299, -300,! 1.75
     & -317, -339, -346, -343, -321, -280, -220, -138,  -39,   65,! 1.75
     &  144,  173,  152,   99,   35,  -21,  -61/                  ! 1.75

      data ross_default(1:nt_ross_c, 15, 3) /                     ! 2.00
     &-1938,-1881,-1842,-1858,-2019,-2374,-2843,-3316,-3634,-3694,! 2.00
     &-3576,-3397,-3224,-3092,-3017,-3002,-3029,-3050,-3006,-2864,! 2.00
     &-2657,-2295,-1911,-1510,-1089, -651, -211,  194,  501,  646,! 2.00
     &  636,  458,  235,   66,  -49, -125, -195, -248, -261, -261,! 2.00
     & -279, -310, -327, -331, -314, -276, -217, -136,  -38,   66,! 2.00
     &  146,  174,  153,   99,   35,  -21,  -61/                  ! 2.00

      data ross_default(1:nt_ross_c, 16, 3) /                     ! 2.25
     &-1936,-1877,-1829,-1818,-1903,-2144,-2529,-2974,-3348,-3501,! 2.25
     &-3439,-3277,-3099,-2951,-2854,-2817,-2828,-2854,-2838,-2731,! 2.25
     &-2545,-2200,-1828,-1440,-1035, -609, -174,  240,  583,  787,! 2.25
     &  826,  668,  428,  223,   77,  -27, -113, -185, -213, -215,! 2.25
     & -230, -270, -299, -312, -303, -270, -212, -133,  -35,   67,! 2.25
     &  149,  177,  154,  100,   35,  -21,  -61/                  ! 2.25

      data ross_default(1:nt_ross_c, 17, 3) /                     ! 2.50
     &-1934,-1872,-1816,-1778,-1792,-1928,-2231,-2635,-3039,-3282,! 2.50
     &-3289,-3149,-2969,-2807,-2690,-2629,-2622,-2645,-2650,-2578,! 2.50
     &-2418,-2093,-1734,-1358, -967, -556, -131,  286,  653,  909,! 2.50
     & 1004,  886,  639,  401,  226,   92,  -10, -105, -153, -160,! 2.50
     & -171, -217, -261, -286, -288, -261, -207, -129,  -33,   69,! 2.50
     &  152,  179,  155,  100,   35,  -21,  -61/                  ! 2.50

      data ross_default(1:nt_ross_c, 18, 3) /                     ! 2.75
     &-1932,-1869,-1810,-1763,-1749,-1817,-2017,-2338,-2713,-3010,! 2.75
     &-3096,-3001,-2832,-2664,-2530,-2448,-2420,-2430,-2445,-2405,! 2.75
     &-2276,-1977,-1630,-1266, -889, -494,  -81,  332,  713, 1008,! 2.75
     & 1162, 1103,  862,  602,  400,  236,  110,   -4,  -74,  -94,! 2.75
     & -104, -148, -206, -247, -264, -246, -199, -123,  -29,   72,! 2.75
     &  155,  184,  157,  101,   36,  -21,  -61/                  ! 2.75

      data ross_default(1:nt_ross_c, 19, 3) /                     ! 3.00
     &-1929,-1866,-1804,-1748,-1708,-1711,-1815,-2055,-2389,-2719,! 3.00
     &-2886,-2846,-2694,-2521,-2373,-2270,-2220,-2215,-2231,-2216,! 3.00
     &-2122,-1852,-1520,-1168, -803, -422,  -24,  382,  768, 1091,! 3.00
     & 1297, 1314, 1091,  817,  589,  401,  252,  119,   22,  -15,! 3.00
     &  -25,  -64, -135, -194, -229, -226, -187, -116,  -23,   75,! 3.00
     &  158,  189,  160,  102,   36,  -20,  -61/                  ! 3.00

      data ross_default(1:nt_ross_c, 20, 3) /                     ! 3.20
     &-1925,-1862,-1800,-1741,-1693,-1675,-1731,-1898,-2167,-2476,! 3.20
     &-2686,-2699,-2573,-2405,-2250,-2134,-2067,-2048,-2057,-2055,! 3.20
     &-1986,-1746,-1427,-1084, -729, -360,   26,  424,  810, 1147,! 3.20
     & 1386, 1472, 1276, 1000,  754,  552,  394,  239,  118,   63,! 3.20
     &   45,   13,  -63, -137, -189, -202, -172, -107,  -17,   80,! 3.20
     &  162,  194,  163,  103,   37,  -20,  -61/                  ! 3.20

      data ross_default(1:nt_ross_c, 21, 3) /                     ! 3.40
     &-1921,-1858,-1796,-1735,-1679,-1641,-1650,-1748,-1953,-2233,! 3.40
     &-2475,-2544,-2450,-2289,-2129,-2000,-1918,-1883,-1883,-1887,! 3.40
     &-1843,-1635,-1332, -998, -652, -293,   81,  469,  851, 1197,! 3.40
     & 1463, 1619, 1459, 1186,  926,  712,  554,  378,  229,  154,! 3.40
     &  126,   99,   20,  -68, -138, -169, -153,  -96,  -10,   85,! 3.40
     &  166,  200,  168,  105,   38,  -20,  -61/                  ! 3.40

      data ross_default(1:nt_ross_c, 22, 3) /                     ! 3.60
     &-1915,-1853,-1790,-1728,-1668,-1615,-1592,-1636,-1778,-2009,! 3.60
     &-2256,-2374,-2318,-2171,-2009,-1871,-1774,-1724,-1712,-1717,! 3.60
     &-1691,-1518,-1232, -909, -572, -223,  139,  516,  893, 1243,! 3.60
     & 1528, 1750, 1638, 1376, 1106,  882,  712,  532,  357,  261,! 3.60
     &  220,  193,  117,   16,  -73, -125, -126,  -80,    0,   92,! 3.60
     &  172,  206,  173,  108,   39,  -19,  -60/                  ! 3.60

      data ross_default(1:nt_ross_c, 23, 3) /                     ! 3.80
     &-1907,-1845,-1783,-1721,-1658,-1598,-1556,-1559,-1640,-1810,! 3.80
     &-2033,-2187,-2175,-2049,-1890,-1745,-1636,-1571,-1546,-1545,! 3.80
     &-1532,-1394,-1129, -817, -489, -150,  201,  567,  937, 1287,! 3.80
     & 1584, 1865, 1810, 1567, 1293, 1060,  864,  699,  503,  386,! 3.80
     &  328,  298,  228,  116,    7,  -68,  -89,  -57,   14,  102,! 3.80
     &  179,  214,  181,  112,   41,  -18,  -59/                  ! 3.80

      data ross_default(1:nt_ross_c, 24, 3) /                     ! 4.00
     &-1899,-1838,-1777,-1714,-1649,-1582,-1521,-1486,-1509,-1620,! 4.00
     &-1812,-1991,-2028,-1927,-1772,-1622,-1502,-1422,-1383,-1375,! 4.00
     &-1368,-1264,-1022, -723, -404,  -74,  267,  621,  982, 1330,! 4.00
     & 1635, 1964, 1973, 1757, 1482, 1241, 1026,  876,  660,  525,! 4.00
     &  450,  413,  349,  229,  103,    3,  -42,  -28,   32,  115,! 4.00
     &  188,  223,  190,  116,   43,  -17,  -59/                  ! 4.00

      data ross_default(1:nt_ross_c, 25, 3) /                     ! 4.20
     &-1888,-1829,-1768,-1706,-1640,-1570,-1501,-1448,-1437,-1495,! 4.20
     &-1632,-1795,-1863,-1793,-1651,-1501,-1376,-1283,-1229,-1209,! 4.20
     &-1201,-1125, -911, -625, -315,    4,  335,  679, 1029, 1372,! 4.20
     & 1681, 2048, 2122, 1944, 1677, 1430, 1213, 1037,  834,  685,! 4.20
     &  591,  541,  483,  360,  218,   93,   21,   12,   58,  133,! 4.20
     &  202,  234,  202,  124,   47,  -14,  -57/                  ! 4.20

      data ross_default(1:nt_ross_c, 26, 3) /                     ! 4.40
     &-1878,-1821,-1759,-1697,-1632,-1559,-1483,-1412,-1368,-1377,! 4.40
     &-1459,-1598,-1692,-1657,-1531,-1381,-1252,-1147,-1079,-1046,! 4.40
     &-1034, -979, -795, -525, -225,   85,  406,  739, 1079, 1416,! 4.40
     & 1726, 2120, 2257, 2126, 1873, 1620, 1403, 1207, 1016,  856,! 4.40
     &  745,  682,  626,  504,  347,  199,   99,   64,   91,  155,! 4.40
     &  219,  248,  216,  133,   52,  -12,  -55/                  ! 4.40

      data ross_default(1:nt_ross_c, 27, 3) /                     ! 4.60
     &-1864,-1809,-1749,-1688,-1623,-1550,-1468,-1385,-1317,-1288,! 4.60
     &-1322,-1423,-1521,-1516,-1408,-1263,-1128,-1012, -932, -887,! 4.60
     & -867, -827, -672, -421, -132,  169,  481,  802, 1132, 1461,! 4.60
     & 1769, 2182, 2375, 2300, 2068, 1815, 1596, 1392, 1206, 1039,! 4.60
     &  914,  836,  778,  661,  493,  323,  194,  131,  135,  185,! 4.60
     &  241,  266,  234,  146,   59,   -8,  -52/                  ! 4.60

      data ross_default(1:nt_ross_c, 28, 3) /                     ! 4.80
     &-1847,-1795,-1738,-1678,-1615,-1542,-1457,-1365,-1282,-1225,! 4.80
     &-1218,-1273,-1354,-1369,-1283,-1145,-1006, -882, -790, -732,! 4.80
     & -702, -668, -543, -312,  -36,  256,  558,  869, 1188, 1508,! 4.80
     & 1812, 2237, 2477, 2463, 2262, 2013, 1793, 1590, 1403, 1233,! 4.80
     & 1096, 1004,  938,  828,  652,  464,  307,  214,  191,  223,! 4.80
     &  270,  290,  255,  164,   68,   -2,  -48/                  ! 4.80

      data ross_default(1:nt_ross_c, 29, 3) /                     ! 5.00
     &-1831,-1781,-1728,-1669,-1607,-1534,-1446,-1348,-1250,-1168,! 5.00
     &-1121,-1131,-1188,-1220,-1158,-1029, -885, -755, -652, -581,! 5.00
     & -541, -507, -408, -201,   62,  345,  638,  938, 1247, 1557,! 5.00
     & 1856, 2288, 2565, 2612, 2452, 2212, 1989, 1789, 1602, 1430,! 5.00
     & 1283, 1179, 1105, 1002,  821,  617,  433,  309,  258,  270,! 5.00
     &  304,  318,  281,  186,   81,    4,  -44/                  ! 5.00

      data ross_default(1:nt_ross_c, 30, 3) /                     ! 5.20
     &-1797,-1751,-1701,-1646,-1586,-1515,-1428,-1328,-1222,-1126,! 5.20
     &-1057,-1035,-1056,-1076,-1026, -907, -765, -630, -518, -436,! 5.20
     & -385, -344, -265,  -82,  166,  438,  721, 1010, 1309, 1610,! 5.20
     & 1902, 2336, 2639, 2744, 2634, 2413, 2190, 1993, 1808, 1636,! 5.20
     & 1485, 1369, 1283, 1182, 1002,  786,  580,  427,  346,  331,! 5.20
     &  350,  357,  315,  217,  101,   16,  -36/                  ! 5.20

      data ross_default(1:nt_ross_c, 31, 3) /                     ! 5.40
     &-1764,-1721,-1675,-1624,-1566,-1497,-1411,-1310,-1197,-1088,! 5.40
     & -999, -945, -931, -934, -895, -788, -648, -509, -389, -296,! 5.40
     & -233, -182, -117,   40,  272,  534,  807, 1087, 1374, 1665,! 5.40
     & 1950, 2383, 2706, 2860, 2806, 2612, 2392, 2197, 2013, 1844,! 5.40
     & 1690, 1564, 1465, 1365, 1189,  963,  737,  556,  444,  403,! 5.40
     &  404,  402,  355,  253,  125,   31,  -26/                  ! 5.40

      data ross_default(1:nt_ross_c, 32, 3) /                     ! 5.60
     &-1737,-1697,-1654,-1607,-1551,-1484,-1399,-1296,-1179,-1060,! 5.60
     & -955, -876, -832, -812, -770, -671, -533, -391, -264, -161,! 5.60
     &  -87,  -22,   34,  169,  383,  633,  896, 1167, 1443, 1723,! 5.60
     & 2000, 2429, 2765, 2961, 2964, 2807, 2595, 2402, 2223, 2055,! 5.60
     & 1899, 1765, 1657, 1551, 1381, 1149,  908,  702,  560,  490,! 5.60
     &  470,  457,  405,  299,  160,   51,  -13/                  ! 5.60

      data ross_default(1:nt_ross_c, 33, 3) /                     ! 5.80
     &-1713,-1678,-1638,-1594,-1542,-1476,-1392,-1287,-1166,-1040,! 5.80
     & -924, -828, -760, -712, -655, -556, -420, -275, -142,  -31,! 5.80
     &   54,  133,  191,  305,  499,  736,  989, 1250, 1516, 1785,! 5.80
     & 2054, 2476, 2820, 3047, 3106, 2994, 2800, 2608, 2434, 2268,! 5.80
     & 2113, 1974, 1855, 1741, 1577, 1342, 1089,  864,  694,  593,! 5.80
     &  549,  523,  466,  355,  207,   81,    5/                  ! 5.80

      data ross_default(1:nt_ross_c, 34, 3) /                     ! 6.00
     &-1689,-1657,-1622,-1582,-1532,-1467,-1384,-1278,-1154,-1022,! 6.00
     & -896, -784, -693, -619, -545, -446, -312, -164,  -26,   94,! 6.00
     &  190,  286,  347,  444,  619,  842, 1085, 1336, 1592, 1851,! 6.00
     & 2110, 2524, 2873, 3125, 3234, 3173, 3002, 2814, 2643, 2481,! 6.00
     & 2327, 2183, 2055, 1933, 1773, 1537, 1274, 1032,  836,  706,! 6.00
     &  637,  596,  533,  420,  263,  118,   27/                  ! 6.00

      data ross_default(1:nt_ross_c, 35, 3) /                     ! 6.25
     &-1643,-1618,-1590,-1556,-1512,-1452,-1369,-1264,-1138,-1002,! 6.25
     & -871, -749, -640, -541, -441, -326, -186,  -34,  112,  242,! 6.25
     &  351,  467,  540,  626,  777,  983, 1211, 1449, 1692, 1937,! 6.25
     & 2185, 2586, 2939, 3210, 3367, 3373, 3248, 3075, 2909, 2751,! 6.25
     & 2599, 2453, 2317, 2183, 2021, 1791, 1522, 1266, 1046,  883,! 6.25
     &  779,  712,  639,  521,  356,  189,   75/                  ! 6.25

      data ross_default(1:nt_ross_c, 36, 3) /                     ! 6.50
     &-1593,-1575,-1554,-1527,-1490,-1434,-1354,-1248,-1121, -984,! 6.50
     & -847, -716, -592, -470, -345, -214,  -69,   86,  240,  381,! 6.50
     &  501,  639,  729,  810,  941, 1128, 1342, 1567, 1797, 2029,! 6.50
     & 2264, 2652, 3005, 3290, 3484, 3551, 3481, 3332, 3173, 3020,! 6.50
     & 2870, 2723, 2579, 2435, 2269, 2045, 1772, 1505, 1264, 1070,! 6.50
     &  934,  842,  755,  635,  467,  281,  143/                  ! 6.50

      data ross_default(1:nt_ross_c, 37, 3) /                     ! 6.75
     &-1507,-1496,-1482,-1464,-1435,-1388,-1315,-1214,-1092, -958,! 6.75
     & -823, -689, -556, -418, -273, -124,   31,  194,  355,  506,! 6.75
     &  639,  797,  907,  993, 1110, 1280, 1481, 1694, 1911, 2130,! 6.75
     & 2353, 2724, 3072, 3366, 3584, 3701, 3691, 3582, 3438, 3292,! 6.75
     & 3146, 3000, 2851, 2696, 2520, 2301, 2031, 1756, 1505, 1292,! 6.75
     & 1126, 1004,  898,  772,  601,  403,  236/                  ! 6.75

      data ross_default(1:nt_ross_c, 38, 3) /                     ! 7.00
     &-1416,-1412,-1405,-1395,-1375,-1337,-1272,-1177,-1058, -927,! 7.00
     & -792, -657, -516, -365, -205,  -40,  125,  293,  460,  619,! 7.00
     &  764,  943, 1075, 1173, 1282, 1437, 1624, 1825, 2029, 2237,! 7.00
     & 2448, 2802, 3142, 3442, 3679, 3834, 3881, 3819, 3697, 3561,! 7.00
     & 3420, 3276, 3123, 2957, 2771, 2555, 2292, 2009, 1749, 1518,! 7.00
     & 1326, 1176, 1052,  919,  749,  546,  355/                  ! 7.00

      data ross_default(1:nt_ross_c, 39, 3) /                     ! 7.25
     &-1273,-1274,-1278,-1274,-1261,-1235,-1184,-1104, -999, -877,! 7.25
     & -748, -613, -467, -309, -141,   32,  207,  382,  553,  718,! 7.25
     &  872, 1071, 1224, 1338, 1448, 1592, 1768, 1960, 2155, 2352,! 7.25
     & 2552, 2888, 3218, 3517, 3767, 3950, 4042, 4032, 3946, 3830,! 7.25
     & 3701, 3558, 3401, 3224, 3025, 2805, 2549, 2273, 2011, 1772,! 7.25
     & 1561, 1386, 1237, 1090,  918,  714,  509/                  ! 7.25

      data ross_default(1:nt_ross_c, 40, 3) /                     ! 7.50
     &-1130,-1136,-1149,-1149,-1143,-1125,-1086,-1020, -928, -814,! 7.50
     & -689, -554, -406, -245,  -73,  105,  285,  464,  639,  808,! 7.50
     &  968, 1184, 1359, 1493, 1610, 1747, 1914, 2096, 2284, 2471,! 7.50
     & 2663, 2982, 3299, 3592, 3855, 4059, 4189, 4227, 4181, 4091,! 7.50
     & 3978, 3840, 3679, 3491, 3278, 3054, 2806, 2538, 2274, 2027,! 7.50
     & 1797, 1599, 1428, 1270, 1096,  898,  689/                  ! 7.50

      data ross_default(1:nt_ross_c, 41, 3) /                     ! 7.75
     & -955, -964, -975, -977, -974, -968, -942, -894, -820, -721,! 7.75
     & -605, -471, -324, -165,    3,  179,  360,  540,  716,  886,! 7.75
     & 1050, 1277, 1471, 1626, 1756, 1892, 2053, 2228, 2409, 2588,! 7.75
     & 2773, 3077, 3379, 3673, 3940, 4160, 4318, 4397, 4395, 4335,! 7.75
     & 4238, 4107, 3950, 3755, 3531, 3295, 3050, 2789, 2528, 2286,! 7.75
     & 2056, 1844, 1653, 1475, 1293, 1093,  883/                  ! 7.75

      data ross_default(1:nt_ross_c, 42, 3) /                     ! 8.00
     & -783, -793, -803, -806, -804, -807, -788, -752, -694, -610,! 8.00
     & -504, -376, -232,  -76,   87,  258,  435,  614,  789,  959,! 8.00
     & 1124, 1357, 1566, 1742, 1889, 2031, 2188, 2359, 2533, 2706,! 8.00
     & 2888, 3177, 3466, 3758, 4027, 4261, 4442, 4556, 4594, 4563,! 8.00
     & 4484, 4364, 4213, 4014, 3783, 3534, 3292, 3039, 2781, 2545,! 8.00
     & 2314, 2089, 1880, 1686, 1497, 1297, 1088/                  ! 8.00

      data ross_default(1:nt_ross_c,  1, 4) /                     !-4.00
     &-4997,-4894,-4750,-4583,-4429,-4310,-4234,-4206,-4209,-4207,!-4.00
     &-4162,-4030,-3801,-3500,-3153,-2780,-2399,-2021,-1652,-1300,!-4.00
     & -979, -640, -532, -515, -516, -521, -524, -523, -507, -492,!-4.00
     & -487, -480, -484, -486, -483, -476, -453, -449, -444, -439,!-4.00
     & -431, -417, -401, -378, -341, -289, -218, -129,  -25,   79,!-4.00
     &  159,  191,  169,  112,   45,  -14,  -56/                  !-4.00

      data ross_default(1:nt_ross_c,  2, 4) /                     !-3.50
     &-4993,-4936,-4815,-4664,-4500,-4358,-4255,-4198,-4187,-4194,!-3.50
     &-4179,-4103,-3928,-3664,-3346,-2994,-2626,-2256,-1891,-1538,!-3.50
     &-1203, -780, -565, -516, -511, -515, -520, -522, -515, -496,!-3.50
     & -487, -478, -479, -484, -482, -476, -456, -447, -443, -438,!-3.50
     & -430, -417, -400, -376, -340, -289, -218, -129,  -25,   79,!-3.50
     &  159,  191,  169,  112,   45,  -14,  -56/                  !-3.50

      data ross_default(1:nt_ross_c,  3, 4) /                     !-3.00
     &-4952,-4949,-4865,-4735,-4578,-4421,-4292,-4204,-4168,-4170,!-3.00
     &-4174,-4141,-4026,-3811,-3524,-3196,-2845,-2485,-2127,-1776,!-3.00
     &-1438, -974, -646, -528, -506, -507, -513, -518, -517, -502,!-3.00
     & -487, -476, -472, -480, -480, -475, -461, -446, -442, -436,!-3.00
     & -430, -416, -398, -375, -340, -288, -218, -128,  -25,   79,!-3.00
     &  159,  191,  169,  112,   45,  -14,  -56/                  !-3.00

      data ross_default(1:nt_ross_c,  4, 4) /                     !-2.50
     &-4814,-4919,-4893,-4790,-4653,-4493,-4344,-4228,-4158,-4142,!-2.50
     &-4152,-4147,-4088,-3931,-3685,-3383,-3052,-2706,-2357,-2011,!-2.50
     &-1674,-1195, -792, -567, -506, -498, -504, -511, -514, -508,!-2.50
     & -490, -475, -466, -473, -477, -472, -463, -444, -440, -434,!-2.50
     & -428, -415, -397, -373, -339, -288, -218, -128,  -24,   79,!-2.50
     &  159,  191,  169,  112,   45,  -14,  -56/                  !-2.50

      data ross_default(1:nt_ross_c,  5, 4) /                     !-2.00
     &-4470,-4796,-4878,-4825,-4713,-4568,-4409,-4268,-4167,-4117,!-2.00
     &-4118,-4130,-4111,-4018,-3824,-3555,-3247,-2918,-2579,-2241,!-2.00
     &-1908,-1425, -985, -658, -519, -489, -490, -499, -506, -507,!-2.00
     & -494, -473, -460, -463, -472, -470, -462, -444, -437, -432,!-2.00
     & -425, -414, -395, -372, -338, -287, -217, -127,  -24,   79,!-2.00
     &  159,  191,  169,  112,   45,  -14,  -56/                  !-2.00

      data ross_default(1:nt_ross_c,  6, 4) /                     !-1.50
     &-3888,-4468,-4769,-4824,-4752,-4631,-4479,-4322,-4192,-4106,!-1.50
     &-4078,-4091,-4100,-4061,-3931,-3707,-3426,-3116,-2792,-2463,!-1.50
     &-2135,-1655,-1200, -806, -561, -482, -471, -480, -491, -499,!-1.50
     & -495, -471, -456, -451, -463, -465, -458, -444, -434, -429,!-1.50
     & -422, -413, -394, -370, -336, -287, -217, -127,  -23,   80,!-1.50
     &  159,  191,  169,  112,   45,  -14,  -56/                  !-1.50

      data ross_default(1:nt_ross_c,  7, 4) /                     !-1.00
     &-3194,-3895,-4451,-4726,-4756,-4670,-4540,-4381,-4228,-4111,!-1.00
     &-4045,-4038,-4059,-4061,-3995,-3830,-3586,-3299,-2991,-2673,!-1.00
     &-2353,-1878,-1418, -990, -652, -483, -443, -447, -463, -478,!-1.00
     & -485, -467, -451, -438, -449, -458, -453, -443, -429, -425,!-1.00
     & -419, -410, -393, -368, -334, -286, -216, -126,  -22,   80,!-1.00
     &  160,  191,  169,  112,   45,  -14,  -56/                  !-1.00

      data ross_default(1:nt_ross_c,  8, 4) /                     !-0.50
     &-2555,-3202,-3879,-4411,-4664,-4671,-4574,-4430,-4268,-4122,!-0.50
     &-4019,-3977,-3990,-4014,-4003,-3907,-3714,-3457,-3169,-2866,!-0.50
     &-2556,-2089,-1627,-1182, -784, -508, -402, -391, -410, -436,!-0.50
     & -456, -457, -441, -425, -429, -444, -444, -436, -423, -419,!-0.50
     & -414, -406, -391, -366, -332, -284, -216, -126,  -21,   81,!-0.50
     &  160,  191,  169,  112,   45,  -14,  -56/                  !-0.50

      data ross_default(1:nt_ross_c,  9, 4) /                     ! 0.00
     &-2120,-2562,-3184,-3833,-4345,-4572,-4559,-4447,-4290,-4126,! 0.00
     &-3990,-3906,-3889,-3919,-3944,-3915,-3788,-3575,-3313,-3028,! 0.00
     &-2731,-2275,-1816,-1361, -928, -565, -355, -299, -313, -350,! 0.00
     & -389, -425, -420, -409, -403, -422, -429, -424, -414, -410,! 0.00
     & -407, -400, -388, -364, -329, -282, -215, -126,  -20,   82,! 0.00
     &  160,  192,  169,  112,   45,  -14,  -56/                  ! 0.00

      data ross_default(1:nt_ross_c, 10, 4) /                     ! 0.50
     &-1945,-2104,-2544,-3134,-3758,-4239,-4437,-4403,-4272,-4102,! 0.50
     &-3939,-3817,-3756,-3763,-3805,-3827,-3775,-3622,-3395,-3132,! 0.50
     &-2851,-2414,-1963,-1505,-1051, -633, -317, -171, -158, -198,! 0.50
     & -256, -340, -370, -375, -370, -388, -404, -404, -398, -395,! 0.50
     & -396, -391, -382, -360, -326, -279, -213, -125,  -19,   84,! 0.50
     &  161,  192,  169,  112,   45,  -14,  -56/                  ! 0.50

      data ross_default(1:nt_ross_c, 11, 4) /                     ! 1.00
     &-1893,-1903,-2076,-2495,-3056,-3640,-4078,-4243,-4184,-4030,! 1.00
     &-3854,-3697,-3591,-3552,-3578,-3626,-3637,-3557,-3380,-3145,! 1.00
     &-2883,-2469,-2035,-1586,-1128, -681, -288,  -28,   58,   33,! 1.00
     &  -36, -170, -261, -300, -315, -335, -364, -371, -368, -368,! 1.00
     & -377, -378, -372, -355, -322, -276, -210, -123,  -19,   87,! 1.00
     &  163,  193,  170,  112,   45,  -14,  -56/                  ! 1.00

      data ross_default(1:nt_ross_c, 12, 4) /                     ! 1.25
     &-1885,-1871,-1964,-2254,-2728,-3289,-3790,-4072,-4093,-3969,! 1.25
     &-3794,-3625,-3498,-3435,-3440,-3485,-3517,-3474,-3327,-3110,! 1.25
     &-2858,-2457,-2035,-1595,-1142, -689, -273,   38,  180,  178,! 1.25
     &  109,  -46, -172, -237, -271, -297, -335, -348, -346, -348,! 1.25
     & -361, -367, -364, -350, -320, -273, -208, -122,  -18,   88,! 1.25
     &  165,  193,  170,  112,   45,  -14,  -56/                  ! 1.25

      data ross_default(1:nt_ross_c, 13, 4) /                     ! 1.50
     &-1877,-1840,-1857,-2029,-2422,-2942,-3473,-3857,-3978,-3891,! 1.50
     &-3721,-3542,-3395,-3305,-3286,-3322,-3366,-3356,-3244,-3048,! 1.50
     &-2808,-2418,-2009,-1582,-1137, -686, -254,   99,  302,  337,! 1.50
     &  277,  104,  -57, -153, -210, -246, -296, -320, -320, -321,! 1.50
     & -339, -353, -354, -344, -316, -271, -206, -121,  -17,   89,! 1.50
     &  166,  194,  170,  112,   45,  -14,  -56/                  ! 1.50

      data ross_default(1:nt_ross_c, 14, 4) /                     ! 1.75
     &-1873,-1830,-1821,-1914,-2186,-2621,-3127,-3567,-3791,-3776,! 1.75
     &-3629,-3449,-3287,-3175,-3130,-3147,-3191,-3204,-3129,-2959,! 1.75
     &-2733,-2357,-1961,-1547,-1114, -669, -230,  153,  413,  500,! 1.75
     &  459,  280,   85,  -44, -129, -182, -244, -283, -288, -289,! 1.75
     & -309, -332, -339, -335, -311, -268, -204, -119,  -16,   90,! 1.75
     &  169,  195,  171,  112,   45,  -14,  -56/                  ! 1.75

      data ross_default(1:nt_ross_c, 15, 4) /                     ! 2.00
     &-1870,-1819,-1785,-1805,-1966,-2319,-2786,-3254,-3572,-3641,! 2.00
     &-3525,-3346,-3171,-3038,-2966,-2960,-2997,-3027,-2987,-2847,! 2.00
     &-2639,-2276,-1892,-1493,-1074, -639, -200,  203,  510,  657,! 2.00
     &  651,  477,  255,   86,  -27, -101, -175, -235, -249, -248,! 2.00
     & -269, -303, -320, -323, -304, -263, -201, -117,  -15,   91,! 2.00
     &  171,  197,  171,  113,   45,  -14,  -56/                  ! 2.00

      data ross_default(1:nt_ross_c, 16, 4) /                     ! 2.25
     &-1869,-1815,-1773,-1765,-1852,-2094,-2477,-2918,-3287,-3447,! 2.25
     &-3391,-3230,-3051,-2902,-2807,-2776,-2796,-2829,-2818,-2712,! 2.25
     &-2526,-2181,-1809,-1422,-1018, -596, -164,  249,  592,  798,! 2.25
     &  839,  687,  448,  243,  100,   -1,  -90, -170, -200, -202,! 2.25
     & -219, -261, -291, -304, -293, -257, -196, -113,  -13,   92,! 2.25
     &  174,  199,  172,  113,   45,  -14,  -56/                  ! 2.25

      data ross_default(1:nt_ross_c, 17, 4) /                     ! 2.50
     &-1867,-1811,-1761,-1727,-1744,-1882,-2184,-2587,-2986,-3231,! 2.50
     &-3245,-3107,-2926,-2763,-2646,-2589,-2590,-2620,-2629,-2559,! 2.50
     &-2399,-2074,-1714,-1340, -951, -543, -120,  295,  662,  919,! 2.50
     & 1016,  904,  659,  421,  248,  117,   14,  -87, -139, -146,! 2.50
     & -158, -207, -252, -277, -278, -248, -191, -110,  -10,   94,! 2.50
     &  177,  202,  173,  113,   45,  -14,  -56/                  ! 2.50

      data ross_default(1:nt_ross_c, 18, 4) /                     ! 2.75
     &-1866,-1809,-1756,-1713,-1703,-1773,-1974,-2295,-2665,-2960,! 2.75
     &-3053,-2962,-2795,-2626,-2492,-2412,-2389,-2405,-2423,-2385,! 2.75
     &-2257,-1956,-1610,-1248, -873, -480,  -69,  342,  722, 1018,! 2.75
     & 1173, 1119,  881,  622,  421,  260,  136,   16,  -59,  -79,! 2.75
     &  -90, -136, -196, -238, -253, -233, -183, -104,   -6,   97,! 2.75
     &  181,  207,  176,  114,   45,  -14,  -56/                  ! 2.75

      data ross_default(1:nt_ross_c, 19, 4) /                     ! 3.00
     &-1864,-1807,-1751,-1699,-1663,-1670,-1776,-2017,-2350,-2676,! 3.00
     &-2847,-2812,-2661,-2488,-2339,-2237,-2190,-2190,-2209,-2196,! 3.00
     &-2102,-1832,-1500,-1149, -786, -408,  -12,  392,  777, 1101,! 3.00
     & 1307, 1329, 1110,  836,  609,  424,  278,  141,   38,    0,! 3.00
     &   -9,  -51, -124, -184, -218, -213, -171,  -97,   -1,  100,! 3.00
     &  184,  212,  178,  115,   46,  -14,  -56/                  ! 3.00

      data ross_default(1:nt_ross_c, 20, 4) /                     ! 3.20
     &-1862,-1805,-1748,-1694,-1650,-1635,-1694,-1863,-2131,-2437,! 3.20
     &-2647,-2666,-2543,-2376,-2220,-2104,-2040,-2023,-2035,-2035,! 3.20
     &-1967,-1725,-1407,-1065, -712, -345,   38,  434,  819, 1156,! 3.20
     & 1396, 1486, 1293, 1016,  773,  573,  419,  262,  136,   79,! 3.20
     &   62,   26,  -51, -126, -178, -188, -156,  -88,    4,  105,! 3.20
     &  188,  217,  182,  117,   46,  -13,  -56/                  ! 3.20

      data ross_default(1:nt_ross_c, 21, 4) /                     ! 3.40
     &-1861,-1803,-1745,-1689,-1638,-1603,-1616,-1716,-1921,-2198,! 3.40
     &-2439,-2513,-2424,-2264,-2103,-1974,-1893,-1859,-1862,-1867,! 3.40
     &-1823,-1614,-1311, -979, -635, -278,   93,  479,  861, 1206,! 3.40
     & 1472, 1631, 1475, 1203,  943,  731,  576,  400,  247,  170,! 3.40
     &  144,  114,   32,  -56, -127, -156, -137,  -77,   12,  110,! 3.40
     &  192,  223,  186,  119,   47,  -13,  -56/                  ! 3.40

      data ross_default(1:nt_ross_c, 22, 4) /                     ! 3.60
     &-1858,-1800,-1742,-1684,-1628,-1579,-1560,-1606,-1750,-1980,! 3.60
     &-2224,-2345,-2294,-2148,-1987,-1848,-1751,-1702,-1692,-1697,! 3.60
     &-1671,-1497,-1212, -889, -554, -208,  152,  527,  903, 1252,! 3.60
     & 1537, 1761, 1652, 1391, 1122,  899,  732,  553,  375,  277,! 3.60
     &  238,  209,  130,   28,  -61, -112, -110,  -61,   22,  117,! 3.60
     &  197,  230,  192,  121,   48,  -12,  -55/                  ! 3.60

      data ross_default(1:nt_ross_c, 23, 4) /                     ! 3.80
     &-1854,-1797,-1739,-1680,-1621,-1565,-1526,-1532,-1614,-1784,! 3.80
     &-2005,-2159,-2153,-2029,-1871,-1725,-1615,-1550,-1526,-1526,! 3.80
     &-1512,-1374,-1109, -797, -471, -134,  215,  578,  946, 1296,! 3.80
     & 1593, 1875, 1823, 1581, 1307, 1075,  882,  718,  520,  401,! 3.80
     &  345,  314,  241,  128,   19,  -54,  -73,  -39,   35,  127,! 3.80
     &  205,  238,  200,  125,   50,  -11,  -54/                  ! 3.80

      data ross_default(1:nt_ross_c, 24, 4) /                     ! 4.00
     &-1850,-1793,-1735,-1676,-1614,-1551,-1494,-1461,-1486,-1598,! 4.00
     &-1788,-1968,-2008,-1909,-1755,-1605,-1483,-1403,-1365,-1356,! 4.00
     &-1349,-1244,-1002, -703, -386,  -58,  280,  633,  992, 1338,! 4.00
     & 1644, 1973, 1984, 1769, 1495, 1254, 1042,  893,  677,  539,! 4.00
     &  465,  430,  363,  241,  115,   16,  -26,  -10,   53,  139,! 4.00
     &  214,  246,  209,  130,   52,  -10,  -54/                  ! 4.00

      data ross_default(1:nt_ross_c, 25, 4) /                     ! 4.20
     &-1846,-1790,-1731,-1672,-1610,-1543,-1477,-1426,-1417,-1476,! 4.20
     &-1612,-1774,-1844,-1777,-1636,-1486,-1360,-1266,-1212,-1191,! 4.20
     &-1183,-1105, -891, -605, -297,   20,  349,  690, 1039, 1381,! 4.20
     & 1690, 2056, 2132, 1955, 1689, 1441, 1227, 1053,  850,  699,! 4.20
     &  606,  557,  497,  372,  230,  107,   37,   30,   79,  157,! 4.20
     &  227,  258,  221,  137,   56,   -8,  -52/                  ! 4.20

      data ross_default(1:nt_ross_c, 26, 4) /                     ! 4.40
     &-1842,-1787,-1727,-1668,-1605,-1535,-1461,-1393,-1351,-1360,! 4.40
     &-1442,-1580,-1675,-1643,-1517,-1368,-1238,-1131,-1063,-1029,! 4.40
     &-1016, -960, -775, -505, -207,  101,  421,  751, 1090, 1425,! 4.40
     & 1734, 2127, 2265, 2135, 1883, 1630, 1414, 1220, 1030,  868,! 4.40
     &  758,  696,  640,  515,  359,  213,  114,   82,  111,  179,! 4.40
     &  244,  271,  235,  147,   61,   -5,  -50/                  ! 4.40

      data ross_default(1:nt_ross_c, 27, 4) /                     ! 4.60
     &-1835,-1781,-1723,-1664,-1601,-1530,-1450,-1369,-1303,-1274,! 4.60
     &-1308,-1408,-1507,-1503,-1396,-1252,-1116, -999, -918, -872,! 4.60
     & -851, -809, -653, -402, -114,  185,  495,  814, 1143, 1470,! 4.60
     & 1777, 2189, 2382, 2308, 2077, 1824, 1605, 1404, 1218, 1050,! 4.60
     &  925,  850,  791,  672,  504,  336,  208,  148,  155,  208,! 4.60
     &  265,  289,  253,  160,   68,   -1,  -48/                  ! 4.60

      data ross_default(1:nt_ross_c, 28, 4) /                     ! 4.80
     &-1825,-1774,-1719,-1660,-1598,-1527,-1443,-1353,-1270,-1215,! 4.80
     &-1207,-1262,-1342,-1357,-1272,-1136, -995, -871, -777, -718,! 4.80
     & -688, -652, -525, -294,  -18,  272,  572,  881, 1198, 1517,! 4.80
     & 1820, 2244, 2483, 2469, 2270, 2021, 1800, 1599, 1413, 1242,! 4.80
     & 1105, 1014,  950,  839,  663,  476,  321,  230,  211,  245,! 4.80
     &  294,  312,  274,  178,   78,    4,  -44/                  ! 4.80

      data ross_default(1:nt_ross_c, 29, 4) /                     ! 5.00
     &-1816,-1767,-1715,-1657,-1595,-1523,-1436,-1339,-1241,-1160,! 5.00
     &-1113,-1122,-1179,-1211,-1149,-1020, -877, -746, -641, -570,! 5.00
     & -529, -492, -392, -183,   79,  361,  652,  950, 1257, 1566,! 5.00
     & 1864, 2295, 2571, 2618, 2458, 2218, 1995, 1796, 1610, 1438,! 5.00
     & 1291, 1188, 1115, 1010,  831,  628,  446,  325,  277,  291,! 5.00
     &  328,  341,  300,  200,   90,   11,  -39/                  ! 5.00

      data ross_default(1:nt_ross_c, 30, 4) /                     ! 5.20
     &-1788,-1742,-1692,-1638,-1578,-1508,-1422,-1322,-1217,-1121,! 5.20
     &-1051,-1028,-1049,-1069,-1018, -900, -758, -623, -510, -427,! 5.20
     & -374, -331, -250,  -66,  181,  453,  735, 1022, 1319, 1618,! 5.20
     & 1910, 2342, 2644, 2748, 2638, 2418, 2195, 1999, 1815, 1643,! 5.20
     & 1492, 1377, 1291, 1191, 1012,  797,  592,  442,  363,  352,! 5.20
     &  373,  379,  333,  230,  110,   23,  -31/                  ! 5.20

      data ross_default(1:nt_ross_c, 31, 4) /                     ! 5.40
     &-1760,-1717,-1670,-1619,-1562,-1493,-1408,-1306,-1194,-1085,! 5.40
     & -995, -940, -926, -929, -889, -782, -642, -503, -382, -288,! 5.40
     & -224, -171, -104,   54,  287,  548,  820, 1099, 1384, 1673,! 5.40
     & 1957, 2388, 2710, 2864, 2810, 2616, 2396, 2201, 2020, 1850,! 5.40
     & 1695, 1569, 1473, 1372, 1197,  973,  749,  569,  461,  422,! 5.40
     &  425,  423,  373,  267,  135,   37,  -22/                  ! 5.40

      data ross_default(1:nt_ross_c, 32, 4) /                     ! 5.60
     &-1735,-1695,-1652,-1605,-1549,-1482,-1398,-1294,-1177,-1058,! 5.60
     & -952, -873, -829, -808, -766, -666, -528, -386, -258, -155,! 5.60
     &  -79,  -13,   45,  182,  396,  646,  908, 1178, 1453, 1731,! 5.60
     & 2007, 2434, 2769, 2964, 2967, 2809, 2598, 2405, 2227, 2059,! 5.60
     & 1903, 1770, 1662, 1557, 1387, 1157,  917,  714,  575,  508,! 5.60
     &  490,  477,  423,  313,  169,   58,   -9/                  ! 5.60

      data ross_default(1:nt_ross_c, 33, 4) /                     ! 5.80
     &-1713,-1677,-1637,-1593,-1541,-1475,-1391,-1286,-1165,-1039,! 5.80
     & -922, -826, -758, -710, -652, -553, -417, -272, -138,  -26,! 5.80
     &   59,  140,  199,  315,  510,  748, 1000, 1260, 1525, 1793,! 5.80
     & 2060, 2481, 2823, 3050, 3109, 2997, 2802, 2611, 2437, 2272,! 5.80
     & 2116, 1977, 1859, 1746, 1582, 1348, 1097,  874,  707,  610,! 5.80
     &  568,  542,  483,  368,  216,   87,    9/                  ! 5.80

      data ross_default(1:nt_ross_c, 34, 4) /                     ! 6.00
     &-1689,-1657,-1622,-1581,-1531,-1467,-1383,-1277,-1153,-1020,! 6.00
     & -895, -783, -692, -617, -543, -444, -310, -162,  -23,   97,! 6.00
     &  194,  291,  354,  452,  628,  852, 1094, 1345, 1600, 1858,! 6.00
     & 2116, 2528, 2876, 3127, 3235, 3174, 3004, 2815, 2645, 2484,! 6.00
     & 2330, 2185, 2058, 1936, 1777, 1542, 1281, 1041,  847,  721,! 6.00
     &  655,  614,  549,  433,  272,  124,   32/                  ! 6.00

      data ross_default(1:nt_ross_c, 35, 4) /                     ! 6.25
     &-1643,-1618,-1589,-1556,-1512,-1452,-1369,-1263,-1138,-1002,! 6.25
     & -870, -748, -639, -540, -439, -324, -185,  -33,  113,  244,! 6.25
     &  353,  470,  545,  631,  784,  990, 1219, 1456, 1698, 1944,! 6.25
     & 2190, 2590, 2941, 3211, 3368, 3374, 3249, 3076, 2910, 2753,! 6.25
     & 2601, 2455, 2319, 2185, 2024, 1795, 1527, 1273, 1055,  895,! 6.25
     &  793,  728,  653,  533,  365,  194,   79/                  ! 6.25

      data ross_default(1:nt_ross_c, 36, 4) /                     ! 6.50
     &-1593,-1575,-1554,-1527,-1490,-1434,-1354,-1248,-1121, -983,! 6.50
     & -847, -716, -592, -469, -345, -213,  -69,   86,  241,  382,! 6.50
     &  503,  641,  732,  813,  945, 1133, 1347, 1572, 1802, 2033,! 6.50
     & 2269, 2655, 3007, 3291, 3484, 3552, 3482, 3333, 3173, 3021,! 6.50
     & 2871, 2724, 2580, 2436, 2271, 2049, 1777, 1510, 1271, 1079,! 6.50
     &  945,  855,  768,  646,  475,  286,  147/                  ! 6.50

      data ross_default(1:nt_ross_c, 37, 4) /                     ! 6.75
     &-1507,-1496,-1482,-1464,-1435,-1388,-1315,-1214,-1092, -958,! 6.75
     & -823, -689, -556, -417, -273, -123,   32,  194,  356,  507,! 6.75
     &  640,  798,  908,  995, 1113, 1284, 1485, 1698, 1915, 2134,! 6.75
     & 2356, 2726, 3074, 3367, 3585, 3702, 3691, 3582, 3438, 3293,! 6.75
     & 3147, 3000, 2852, 2697, 2521, 2303, 2033, 1760, 1510, 1299,! 6.75
     & 1135, 1014,  909,  781,  608,  408,  240/                  ! 6.75

      data ross_default(1:nt_ross_c, 38, 4) /                     ! 7.00
     &-1416,-1412,-1405,-1395,-1375,-1337,-1272,-1177,-1058, -927,! 7.00
     & -792, -656, -516, -365, -205,  -40,  125,  293,  460,  620,! 7.00
     &  764,  944, 1075, 1173, 1283, 1438, 1626, 1827, 2033, 2240,! 7.00
     & 2450, 2803, 3143, 3443, 3680, 3834, 3881, 3819, 3697, 3561,! 7.00
     & 3421, 3276, 3123, 2957, 2772, 2557, 2294, 2012, 1752, 1523,! 7.00
     & 1332, 1184, 1061,  927,  755,  551,  358/                  ! 7.00

      data ross_default(1:nt_ross_c, 39, 4) /                     ! 7.25
     &-1273,-1274,-1278,-1274,-1261,-1235,-1184,-1104, -999, -877,! 7.25
     & -748, -613, -467, -309, -141,   32,  207,  382,  553,  718,! 7.25
     &  873, 1071, 1224, 1339, 1449, 1593, 1769, 1961, 2157, 2353,! 7.25
     & 2554, 2890, 3219, 3517, 3768, 3950, 4042, 4032, 3946, 3830,! 7.25
     & 3701, 3558, 3401, 3224, 3025, 2806, 2550, 2275, 2013, 1775,! 7.25
     & 1565, 1391, 1243, 1096,  922,  718,  512/                  ! 7.25

      data ross_default(1:nt_ross_c, 40, 4) /                     ! 7.50
     &-1130,-1136,-1149,-1149,-1143,-1125,-1086,-1020, -928, -814,! 7.50
     & -689, -554, -406, -245,  -73,  105,  285,  464,  639,  808,! 7.50
     &  968, 1184, 1359, 1493, 1610, 1747, 1914, 2097, 2284, 2471,! 7.50
     & 2663, 2983, 3299, 3593, 3855, 4059, 4189, 4227, 4181, 4091,! 7.50
     & 3978, 3840, 3679, 3491, 3278, 3054, 2806, 2539, 2276, 2029,! 7.50
     & 1800, 1603, 1432, 1274, 1100,  901,  691/                  ! 7.50

      data ross_default(1:nt_ross_c, 41, 4) /                     ! 7.75
     & -955, -964, -975, -977, -974, -968, -942, -894, -820, -721,! 7.75
     & -605, -471, -324, -165,    3,  179,  360,  540,  716,  886,! 7.75
     & 1050, 1277, 1471, 1626, 1756, 1892, 2053, 2229, 2409, 2588,! 7.75
     & 2773, 3077, 3380, 3673, 3940, 4160, 4318, 4397, 4395, 4335,! 7.75
     & 4238, 4107, 3950, 3755, 3531, 3295, 3051, 2790, 2529, 2287,! 7.75
     & 2057, 1846, 1655, 1478, 1296, 1095,  885/                  ! 7.75

      data ross_default(1:nt_ross_c, 42, 4) /                     ! 8.00
     & -783, -793, -803, -806, -804, -807, -788, -752, -694, -610,! 8.00
     & -504, -376, -232,  -76,   87,  258,  435,  614,  789,  959,! 8.00
     & 1124, 1357, 1566, 1742, 1889, 2031, 2188, 2359, 2534, 2706,! 8.00
     & 2888, 3177, 3466, 3758, 4027, 4261, 4442, 4556, 4594, 4563,! 8.00
     & 4484, 4364, 4213, 4014, 3783, 3534, 3292, 3039, 2782, 2545,! 8.00
     & 2315, 2090, 1881, 1688, 1498, 1298, 1089/                  ! 8.00

      data ross_default(1:nt_ross_c,  1, 5) /                     !-4.00
     &-4944,-4852,-4718,-4557,-4403,-4284,-4206,-4182,-4194,-4198,!-4.00
     &-4157,-4027,-3798,-3497,-3150,-2777,-2395,-2016,-1647,-1295,!-4.00
     & -973, -634, -525, -508, -510, -516, -521, -521, -505, -490,!-4.00
     & -484, -475, -481, -485, -481, -474, -451, -447, -442, -436,!-4.00
     & -426, -409, -390, -361, -318, -259, -181,  -83,   29,  140,!-4.00
     &  221,  248,  215,  146,   70,    4,  -42/                  !-4.00

      data ross_default(1:nt_ross_c,  2, 5) /                     !-3.50
     &-4934,-4886,-4778,-4634,-4473,-4330,-4225,-4168,-4165,-4181,!-3.50
     &-4172,-4099,-3925,-3662,-3342,-2990,-2622,-2251,-1886,-1532,!-3.50
     &-1197, -773, -558, -507, -502, -508, -515, -518, -512, -493,!-3.50
     & -483, -472, -474, -482, -480, -473, -453, -445, -441, -434,!-3.50
     & -425, -409, -388, -360, -317, -259, -181,  -83,   29,  140,!-3.50
     &  221,  248,  215,  146,   70,    4,  -42/                  !-3.50

      data ross_default(1:nt_ross_c,  3, 5) /                     !-3.00
     &-4887,-4892,-4819,-4701,-4548,-4390,-4259,-4170,-4137,-4150,!-3.00
     &-4163,-4134,-4022,-3807,-3520,-3191,-2840,-2479,-2121,-1769,!-3.00
     &-1431, -966, -638, -518, -496, -498, -506, -512, -513, -499,!-3.00
     & -483, -470, -465, -476, -478, -471, -457, -443, -439, -432,!-3.00
     & -424, -408, -386, -359, -317, -258, -180,  -82,   29,  140,!-3.00
     &  221,  248,  215,  146,   70,    4,  -42/                  !-3.00

      data ross_default(1:nt_ross_c,  4, 5) /                     !-2.50
     &-4736,-4855,-4838,-4749,-4620,-4461,-4309,-4190,-4120,-4111,!-2.50
     &-4133,-4137,-4082,-3927,-3681,-3379,-3047,-2700,-2350,-2004,!-2.50
     &-1666,-1187, -782, -557, -494, -486, -493, -502, -508, -503,!-2.50
     & -485, -468, -457, -467, -474, -469, -458, -441, -437, -430,!-2.50
     & -422, -407, -385, -357, -316, -258, -180,  -82,   29,  140,!-2.50
     &  221,  248,  215,  146,   70,    4,  -42/                  !-2.50

      data ross_default(1:nt_ross_c,  5, 5) /                     !-2.00
     &-4365,-4720,-4815,-4774,-4674,-4532,-4371,-4226,-4121,-4075,!-2.00
     &-4088,-4112,-4102,-4011,-3819,-3550,-3241,-2911,-2572,-2232,!-2.00
     &-1898,-1416, -975, -647, -506, -475, -477, -487, -497, -501,!-2.00
     & -488, -466, -450, -454, -467, -465, -456, -439, -433, -428,!-2.00
     & -420, -406, -384, -355, -315, -257, -179,  -81,   29,  140,!-2.00
     &  221,  248,  215,  146,   70,    4,  -42/                  !-2.00

      data ross_default(1:nt_ross_c,  6, 5) /                     !-1.50
     &-3775,-4367,-4693,-4762,-4703,-4591,-4438,-4276,-4141,-4054,!-1.50
     &-4035,-4062,-4083,-4051,-3924,-3701,-3420,-3109,-2783,-2453,!-1.50
     &-2125,-1644,-1189, -794, -548, -466, -455, -465, -479, -489,!-1.50
     & -487, -463, -444, -439, -456, -460, -452, -438, -429, -425,!-1.50
     & -416, -404, -382, -353, -313, -257, -179,  -81,   30,  140,!-1.50
     &  221,  248,  215,  146,   70,    4,  -42/                  !-1.50

      data ross_default(1:nt_ross_c,  7, 5) /                     !-1.00
     &-3101,-3786,-4353,-4650,-4695,-4622,-4496,-4333,-4174,-4051,!-1.00
     &-3987,-3994,-4032,-4043,-3985,-3822,-3578,-3290,-2981,-2663,!-1.00
     &-2342,-1866,-1406, -978, -639, -468, -425, -429, -447, -464,!-1.00
     & -474, -457, -438, -422, -438, -451, -446, -435, -423, -420,!-1.00
     & -412, -402, -381, -351, -311, -256, -178,  -80,   31,  141,!-1.00
     &  222,  248,  215,  146,   70,    4,  -42/                  !-1.00

      data ross_default(1:nt_ross_c,  8, 5) /                     !-0.50
     &-2481,-3113,-3775,-4315,-4589,-4611,-4523,-4380,-4210,-4056,!-0.50
     &-3950,-3914,-3945,-3987,-3986,-3895,-3704,-3447,-3158,-2854,!-0.50
     &-2543,-2076,-1614,-1170, -771, -494, -385, -370, -390, -417,!-0.50
     & -440, -445, -427, -407, -414, -435, -436, -427, -415, -413,!-0.50
     & -407, -397, -379, -349, -309, -254, -178,  -80,   32,  142,!-0.50
     &  222,  248,  215,  146,   70,    3,  -42/                  !-0.50

      data ross_default(1:nt_ross_c,  9, 5) /                     ! 0.00
     &-2056,-2492,-3098,-3733,-4250,-4498,-4498,-4391,-4230,-4057,! 0.00
     &-3914,-3830,-3824,-3873,-3916,-3897,-3775,-3563,-3300,-3014,! 0.00
     &-2716,-2260,-1801,-1347, -915, -552, -340, -280, -291, -328,! 0.00
     & -368, -408, -403, -388, -382, -408, -419, -413, -404, -402,! 0.00
     & -399, -390, -375, -346, -306, -252, -177,  -79,   33,  143,! 0.00
     &  222,  248,  215,  146,   70,    3,  -42/                  ! 0.00

      data ross_default(1:nt_ross_c, 10, 5) /                     ! 0.50
     &-1886,-2044,-2478,-3053,-3663,-4147,-4362,-4339,-4208,-4032,! 0.50
     &-3861,-3733,-3676,-3699,-3761,-3799,-3756,-3606,-3380,-3115,! 0.50
     &-2833,-2395,-1945,-1488,-1037, -619, -303, -155, -137, -174,! 0.50
     & -231, -318, -349, -352, -344, -369, -391, -391, -384, -384,! 0.50
     & -387, -381, -369, -343, -303, -249, -175,  -78,   34,  145,! 0.50
     &  223,  248,  215,  146,   70,    3,  -42/                  ! 0.50

      data ross_default(1:nt_ross_c, 11, 5) /                     ! 1.00
     &-1836,-1849,-2021,-2434,-2982,-3553,-3990,-4167,-4115,-3961,! 1.00
     &-3777,-3614,-3506,-3475,-3518,-3585,-3609,-3537,-3361,-3125,! 1.00
     &-2862,-2447,-2013,-1566,-1110, -665, -274,  -13,   76,   56,! 1.00
     &   -9, -143, -235, -274, -284, -307, -347, -356, -351, -354,! 1.00
     & -365, -366, -358, -337, -299, -245, -172,  -77,   35,  148,! 1.00
     &  225,  249,  215,  146,   70,    3,  -42/                  ! 1.00

      data ross_default(1:nt_ross_c, 12, 5) /                     ! 1.25
     &-1828,-1818,-1912,-2197,-2662,-3209,-3701,-3988,-4019,-3898,! 1.25
     &-3719,-3544,-3414,-3356,-3375,-3438,-3484,-3450,-3307,-3089,! 1.25
     &-2836,-2433,-2012,-1574,-1123, -673, -259,   53,  197,  200,! 1.25
     &  135,  -17, -144, -208, -238, -266, -314, -332, -329, -332,! 1.25
     & -348, -354, -349, -332, -296, -243, -170,  -76,   36,  149,! 1.25
     &  227,  249,  215,  146,   70,    3,  -42/                  ! 1.25

      data ross_default(1:nt_ross_c, 13, 5) /                     ! 1.50
     &-1820,-1788,-1808,-1979,-2366,-2875,-3394,-3773,-3903,-3821,! 1.50
     &-3649,-3464,-3313,-3225,-3217,-3271,-3330,-3329,-3222,-3026,! 1.50
     &-2785,-2394,-1985,-1559,-1117, -668, -239,  114,  318,  358,! 1.50
     &  303,  134,  -27, -122, -175, -210, -271, -302, -301, -303,! 1.50
     & -324, -339, -339, -326, -293, -241, -168,  -74,   36,  150,! 1.50
     &  229,  250,  215,  146,   70,    3,  -42/                  ! 1.50

      data ross_default(1:nt_ross_c, 14, 5) /                     ! 1.75
     &-1817,-1778,-1773,-1866,-2135,-2562,-3057,-3485,-3712,-3705,! 1.75
     &-3560,-3376,-3211,-3099,-3062,-3093,-3151,-3175,-3105,-2936,! 1.75
     &-2709,-2331,-1935,-1523,-1093, -650, -215,  167,  428,  519,! 1.75
     &  484,  311,  117,  -12,  -92, -143, -214, -262, -268, -268,! 1.75
     & -292, -317, -324, -316, -287, -237, -166,  -72,   38,  151,! 1.75
     &  232,  252,  216,  147,   70,    3,  -42/                  ! 1.75

      data ross_default(1:nt_ross_c, 15, 5) /                     ! 2.00
     &-1814,-1769,-1738,-1760,-1920,-2269,-2728,-3184,-3496,-3572,! 2.00
     &-3460,-3279,-3101,-2966,-2899,-2904,-2955,-2996,-2961,-2823,! 2.00
     &-2614,-2250,-1866,-1467,-1052, -619, -184,  217,  525,  675,! 2.00
     &  675,  508,  288,  119,   10,  -58, -140, -211, -228, -225,! 2.00
     & -250, -286, -303, -304, -280, -233, -163,  -70,   39,  152,! 2.00
     &  234,  253,  216,  147,   70,    3,  -42/                  ! 2.00

      data ross_default(1:nt_ross_c, 16, 5) /                     ! 2.25
     &-1813,-1765,-1727,-1722,-1809,-2048,-2426,-2857,-3215,-3378,! 2.25
     &-3328,-3169,-2988,-2837,-2745,-2722,-2753,-2796,-2790,-2687,! 2.25
     &-2501,-2154,-1782,-1397, -996, -576, -147,  264,  607,  815,! 2.25
     &  861,  717,  482,  277,  138,   42,  -50, -141, -176, -177,! 2.25
     & -197, -243, -273, -284, -269, -226, -158,  -67,   41,  154,! 2.25
     &  237,  256,  218,  147,   70,    4,  -42/                  ! 2.25

      data ross_default(1:nt_ross_c, 17, 5) /                     ! 2.50
     &-1812,-1761,-1715,-1685,-1704,-1842,-2142,-2538,-2925,-3166,! 2.50
     &-3186,-3051,-2871,-2706,-2589,-2537,-2547,-2586,-2601,-2533,! 2.50
     &-2373,-2045,-1686,-1314, -927, -522, -103,  310,  676,  935,! 2.50
     & 1037,  933,  692,  455,  286,  162,   59,  -55, -113, -119,! 2.50
     & -134, -187, -232, -256, -253, -217, -153,  -63,   44,  156,! 2.50
     &  241,  259,  219,  147,   70,    4,  -42/                  ! 2.50

      data ross_default(1:nt_ross_c, 18, 5) /                     ! 2.75
     &-1811,-1759,-1710,-1671,-1664,-1735,-1936,-2252,-2613,-2899,! 2.75
     &-2996,-2912,-2746,-2576,-2442,-2365,-2348,-2371,-2395,-2359,! 2.75
     &-2230,-1929,-1582,-1221, -849, -459,  -51,  357,  737, 1033,! 2.75
     & 1192, 1146,  913,  655,  456,  304,  182,   52,  -30,  -51,! 2.75
     &  -62, -114, -175, -216, -228, -203, -145,  -58,   48,  158,! 2.75
     &  244,  264,  221,  148,   70,    4,  -42/                  ! 2.75

      data ross_default(1:nt_ross_c, 19, 5) /                     ! 3.00
     &-1810,-1757,-1706,-1658,-1626,-1634,-1742,-1981,-2308,-2625,! 3.00
     &-2795,-2766,-2618,-2445,-2295,-2194,-2151,-2157,-2180,-2170,! 3.00
     &-2075,-1804,-1472,-1122, -762, -386,    6,  407,  792, 1115,! 3.00
     & 1324, 1354, 1140,  867,  642,  464,  325,  180,   68,   30,! 3.00
     &   21,  -26, -101, -161, -193, -182, -133,  -51,   53,  162,! 3.00
     &  248,  270,  224,  149,   71,    4,  -42/                  ! 3.00

      data ross_default(1:nt_ross_c, 20, 5) /                     ! 3.20
     &-1809,-1756,-1704,-1654,-1614,-1602,-1662,-1830,-2094,-2391,! 3.20
     &-2598,-2622,-2504,-2338,-2181,-2065,-2003,-1991,-2007,-2008,! 3.20
     &-1940,-1697,-1378,-1038, -688, -323,   57,  450,  834, 1171,! 3.20
     & 1412, 1508, 1321, 1047,  804,  610,  463,  303,  167,  109,! 3.20
     &   94,   53,  -27, -102, -152, -158, -119,  -42,   58,  166,! 3.20
     &  252,  276,  228,  151,   71,    4,  -42/                  ! 3.20

      data ross_default(1:nt_ross_c, 21, 5) /                     ! 3.40
     &-1808,-1755,-1702,-1650,-1602,-1570,-1585,-1685,-1889,-2160,! 3.40
     &-2395,-2473,-2388,-2230,-2069,-1939,-1858,-1828,-1833,-1841,! 3.40
     &-1796,-1586,-1282, -951, -610, -256,  113,  496,  876, 1221,! 3.40
     & 1488, 1651, 1501, 1231,  972,  765,  616,  440,  279,  200,! 3.40
     &  177,  143,   58,  -31, -100, -125,  -99,  -31,   66,  171,! 3.40
     &  256,  282,  232,  153,   72,    5,  -42/                  ! 3.40

      data ross_default(1:nt_ross_c, 22, 5) /                     ! 3.60
     &-1807,-1754,-1700,-1646,-1594,-1548,-1531,-1578,-1721,-1947,! 3.60
     &-2185,-2307,-2261,-2118,-1956,-1816,-1720,-1672,-1664,-1670,! 3.60
     &-1645,-1469,-1183, -862, -529, -185,  172,  544,  918, 1267,! 3.60
     & 1552, 1779, 1676, 1417, 1148,  929,  767,  591,  408,  307,! 3.60
     &  271,  240,  156,   54,  -34,  -81,  -73,  -16,   75,  178,! 3.60
     &  261,  289,  239,  156,   73,    5,  -41/                  ! 3.60

      data ross_default(1:nt_ross_c, 23, 5) /                     ! 3.80
     &-1805,-1752,-1698,-1643,-1588,-1535,-1498,-1506,-1588,-1756,! 3.80
     &-1971,-2124,-2122,-2001,-1844,-1697,-1587,-1522,-1500,-1500,! 3.80
     &-1486,-1346,-1080, -769, -445, -111,  235,  596,  962, 1310,! 3.80
     & 1608, 1892, 1844, 1605, 1331, 1102,  914,  754,  552,  430,! 3.80
     &  377,  346,  268,  154,   47,  -23,  -36,    5,   89,  188,! 3.80
     &  268,  297,  247,  160,   75,    6,  -41/                  ! 3.80

      data ross_default(1:nt_ross_c, 24, 5) /                     ! 4.00
     &-1804,-1751,-1696,-1641,-1583,-1522,-1468,-1438,-1463,-1573,! 4.00
     &-1760,-1937,-1981,-1884,-1732,-1580,-1457,-1376,-1339,-1330,! 4.00
     &-1323,-1216, -974, -675, -359,  -35,  301,  651, 1006, 1353,! 4.00
     & 1658, 1989, 2003, 1791, 1516, 1277, 1070,  925,  708,  566,! 4.00
     &  495,  462,  390,  268,  144,   47,   10,   33,  106,  200,! 4.00
     &  277,  306,  256,  164,   77,    7,  -40/                  ! 4.00

      data ross_default(1:nt_ross_c, 25, 5) /                     ! 4.20
     &-1804,-1751,-1696,-1639,-1580,-1516,-1453,-1404,-1396,-1454,! 4.20
     &-1587,-1746,-1818,-1754,-1615,-1464,-1337,-1242,-1188,-1167,! 4.20
     &-1158,-1078, -862, -577, -271,   44,  370,  709, 1056, 1396,! 4.20
     & 1704, 2070, 2148, 1974, 1708, 1462, 1251, 1081,  878,  724,! 4.20
     &  633,  588,  524,  398,  259,  138,   73,   74,  131,  216,! 4.20
     &  290,  317,  269,  172,   82,   10,  -38/                  ! 4.20

      data ross_default(1:nt_ross_c, 26, 5) /                     ! 4.40
     &-1803,-1751,-1695,-1638,-1578,-1511,-1440,-1373,-1332,-1341,! 4.40
     &-1421,-1556,-1651,-1622,-1498,-1349,-1217,-1109,-1040,-1006,! 4.40
     & -992, -934, -747, -477, -180,  126,  442,  770, 1106, 1439,! 4.40
     & 1748, 2141, 2280, 2152, 1900, 1648, 1434, 1245, 1056,  891,! 4.40
     &  782,  725,  666,  541,  387,  243,  150,  125,  162,  237,! 4.40
     &  306,  331,  284,  182,   86,   12,  -37/                  ! 4.40

      data ross_default(1:nt_ross_c, 27, 5) /                     ! 4.60
     &-1801,-1750,-1694,-1638,-1577,-1508,-1431,-1352,-1286,-1258,! 4.60
     &-1290,-1388,-1486,-1484,-1379,-1235,-1098, -980, -897, -850,! 4.60
     & -828, -783, -626, -374,  -87,  210,  517,  834, 1159, 1485,! 4.60
     & 1791, 2202, 2395, 2322, 2092, 1839, 1622, 1424, 1241, 1070,! 4.60
     &  946,  875,  816,  695,  531,  366,  243,  190,  205,  265,! 4.60
     &  327,  348,  302,  196,   93,   16,  -34/                  ! 4.60

      data ross_default(1:nt_ross_c, 28, 5) /                     ! 4.80
     &-1798,-1748,-1695,-1638,-1578,-1508,-1427,-1338,-1257,-1201,! 4.80
     &-1192,-1245,-1323,-1340,-1257,-1121, -980, -854, -759, -699,! 4.80
     & -667, -628, -499, -267,    7,  297,  594,  901, 1215, 1532,! 4.80
     & 1834, 2256, 2494, 2481, 2282, 2033, 1814, 1616, 1433, 1260,! 4.80
     & 1123, 1037,  973,  860,  688,  505,  354,  271,  259,  301,! 4.80
     &  354,  371,  324,  214,  103,   22,  -30/                  ! 4.80

      data ross_default(1:nt_ross_c, 29, 5) /                     ! 5.00
     &-1795,-1746,-1695,-1638,-1578,-1508,-1422,-1327,-1230,-1148,! 5.00
     &-1100,-1109,-1164,-1196,-1136,-1008, -863, -731, -625, -552,! 5.00
     & -509, -470, -367, -157,  104,  385,  674,  970, 1274, 1581,! 5.00
     & 1877, 2306, 2580, 2627, 2468, 2229, 2005, 1809, 1626, 1454,! 5.00
     & 1305, 1205, 1136, 1031,  853,  655,  478,  364,  324,  345,! 5.00
     &  387,  398,  350,  236,  115,   29,  -26/                  ! 5.00

      data ross_default(1:nt_ross_c, 30, 5) /                     ! 5.20
     &-1773,-1727,-1679,-1625,-1566,-1497,-1412,-1313,-1208,-1112,! 5.20
     &-1042,-1018,-1037,-1056,-1006, -889, -747, -610, -496, -411,! 5.20
     & -357, -311, -227,  -41,  206,  477,  756, 1043, 1336, 1633,! 5.20
     & 1923, 2352, 2653, 2757, 2647, 2427, 2204, 2009, 1827, 1656,! 5.20
     & 1504, 1391, 1309, 1208, 1031,  821,  622,  478,  408,  404,! 5.20
     &  430,  435,  382,  267,  135,   41,  -18/                  ! 5.20

      data ross_default(1:nt_ross_c, 31, 5) /                     ! 5.40
     &-1752,-1709,-1663,-1612,-1555,-1486,-1402,-1300,-1188,-1079,! 5.40
     & -988, -933, -917, -919, -879, -773, -633, -493, -371, -275,! 5.40
     & -209, -153,  -84,   77,  310,  570,  841, 1118, 1401, 1688,! 5.40
     & 1970, 2398, 2718, 2871, 2816, 2623, 2403, 2209, 2029, 1861,! 5.40
     & 1705, 1580, 1487, 1387, 1214,  994,  775,  603,  502,  472,! 5.40
     &  480,  478,  421,  304,  160,   55,   -9/                  ! 5.40

      data ross_default(1:nt_ross_c, 32, 5) /                     ! 5.60
     &-1731,-1691,-1648,-1600,-1545,-1478,-1394,-1291,-1173,-1054,! 5.60
     & -948, -868, -823, -801, -758, -658, -520, -378, -249, -144,! 5.60
     &  -67,    1,   63,  202,  417,  667,  928, 1196, 1469, 1746,! 5.60
     & 2019, 2444, 2776, 2969, 2972, 2815, 2604, 2411, 2234, 2068,! 5.60
     & 1911, 1778, 1673, 1570, 1402, 1176,  941,  744,  613,  554,! 5.60
     &  542,  530,  469,  349,  194,   75,    3/                  ! 5.60

      data ross_default(1:nt_ross_c, 33, 5) /                     ! 5.80
     &-1710,-1674,-1635,-1591,-1538,-1472,-1388,-1283,-1162,-1036,! 5.80
     & -919, -822, -753, -704, -646, -547, -411, -265, -131,  -17,! 5.80
     &   70,  153,  215,  333,  529,  767, 1018, 1277, 1540, 1807,! 5.80
     & 2072, 2489, 2830, 3055, 3113, 3001, 2807, 2615, 2442, 2278,! 5.80
     & 2123, 1984, 1868, 1756, 1594, 1364, 1117,  900,  741,  652,! 5.80
     &  616,  592,  527,  404,  240,  103,   21/                  ! 5.80

      data ross_default(1:nt_ross_c, 34, 5) /                     ! 6.00
     &-1688,-1656,-1621,-1580,-1530,-1466,-1382,-1276,-1152,-1020,! 6.00
     & -893, -781, -689, -614, -539, -440, -306, -158,  -18,  103,! 6.00
     &  202,  301,  366,  467,  644,  869, 1111, 1361, 1614, 1871,! 6.00
     & 2127, 2536, 2882, 3131, 3239, 3177, 3006, 2819, 2649, 2489,! 6.00
     & 2335, 2190, 2063, 1944, 1787, 1555, 1298, 1063,  876,  758,! 6.00
     &  699,  660,  592,  467,  296,  140,   43/                  ! 6.00

      data ross_default(1:nt_ross_c, 35, 5) /                     ! 6.25
     &-1643,-1617,-1589,-1555,-1511,-1451,-1368,-1262,-1137,-1002,! 6.25
     & -869, -747, -637, -537, -437, -322, -182,  -30,  117,  249,! 6.25
     &  359,  477,  554,  643,  797, 1004, 1233, 1470, 1712, 1955,! 6.25
     & 2200, 2597, 2947, 3215, 3371, 3376, 3251, 3078, 2913, 2756,! 6.25
     & 2604, 2459, 2323, 2191, 2031, 1805, 1541, 1291, 1079,  925,! 6.25
     &  831,  769,  692,  565,  388,  210,   90/                  ! 6.25

      data ross_default(1:nt_ross_c, 36, 5) /                     ! 6.50
     &-1593,-1575,-1553,-1527,-1490,-1434,-1353,-1247,-1121, -983,! 6.50
     & -846, -715, -591, -468, -343, -212,  -67,   88,  243,  384,! 6.50
     &  506,  645,  737,  821,  954, 1143, 1359, 1584, 1813, 2045,! 6.50
     & 2278, 2662, 3011, 3294, 3486, 3553, 3483, 3334, 3175, 3022,! 6.50
     & 2873, 2726, 2583, 2440, 2276, 2056, 1787, 1524, 1289, 1103,! 6.50
     &  976,  890,  802,  674,  497,  301,  157/                  ! 6.50

      data ross_default(1:nt_ross_c, 37, 5) /                     ! 6.75
     &-1507,-1495,-1482,-1464,-1435,-1388,-1315,-1214,-1092, -958,! 6.75
     & -822, -689, -555, -417, -272, -123,   33,  195,  357,  508,! 6.75
     &  642,  801,  912, 1000, 1119, 1291, 1493, 1706, 1924, 2143,! 6.75
     & 2364, 2732, 3078, 3369, 3586, 3703, 3692, 3583, 3439, 3294,! 6.75
     & 3148, 3002, 2854, 2699, 2525, 2308, 2041, 1771, 1524, 1317,! 6.75
     & 1158, 1042,  937,  806,  628,  422,  249/                  ! 6.75

      data ross_default(1:nt_ross_c, 38, 5) /                     ! 7.00
     &-1416,-1412,-1405,-1395,-1375,-1337,-1272,-1177,-1058, -927,! 7.00
     & -792, -656, -516, -365, -205,  -40,  126,  294,  461,  620,! 7.00
     &  765,  945, 1077, 1176, 1286, 1442, 1631, 1832, 2037, 2245,! 7.00
     & 2456, 2808, 3146, 3444, 3680, 3835, 3881, 3819, 3698, 3562,! 7.00
     & 3421, 3277, 3124, 2958, 2774, 2560, 2299, 2019, 1762, 1535,! 7.00
     & 1349, 1205, 1083,  948,  772,  563,  367/                  ! 7.00

      data ross_default(1:nt_ross_c, 39, 5) /                     ! 7.25
     &-1273,-1274,-1278,-1274,-1261,-1234,-1184,-1104, -999, -877,! 7.25
     & -748, -613, -467, -309, -140,   32,  208,  382,  554,  719,! 7.25
     &  873, 1072, 1225, 1340, 1450, 1595, 1772, 1964, 2160, 2357,! 7.25
     & 2557, 2892, 3220, 3518, 3768, 3950, 4043, 4032, 3946, 3830,! 7.25
     & 3702, 3559, 3402, 3225, 3027, 2808, 2554, 2280, 2021, 1785,! 7.25
     & 1577, 1406, 1260, 1113,  936,  728,  519/                  ! 7.25

      data ross_default(1:nt_ross_c, 40, 5) /                     ! 7.50
     &-1130,-1136,-1149,-1149,-1143,-1125,-1086,-1020, -928, -814,! 7.50
     & -689, -554, -406, -245,  -73,  105,  285,  464,  639,  808,! 7.50
     &  968, 1184, 1359, 1493, 1611, 1748, 1915, 2098, 2285, 2473,! 7.50
     & 2665, 2984, 3300, 3593, 3855, 4059, 4189, 4227, 4182, 4091,! 7.50
     & 3978, 3840, 3679, 3491, 3279, 3055, 2808, 2542, 2280, 2035,! 7.50
     & 1807, 1613, 1444, 1286, 1110,  909,  697/                  ! 7.50

      data ross_default(1:nt_ross_c, 41, 5) /                     ! 7.75
     & -955, -964, -975, -977, -974, -968, -942, -894, -820, -721,! 7.75
     & -605, -471, -324, -165,    3,  179,  360,  540,  716,  886,! 7.75
     & 1050, 1277, 1471, 1626, 1756, 1893, 2053, 2229, 2410, 2589,! 7.75
     & 2774, 3078, 3380, 3673, 3940, 4160, 4318, 4397, 4395, 4335,! 7.75
     & 4238, 4107, 3950, 3755, 3532, 3296, 3052, 2791, 2532, 2291,! 7.75
     & 2063, 1853, 1663, 1487, 1303, 1102,  889/                  ! 7.75

      data ross_default(1:nt_ross_c, 42, 5) /                     ! 8.00
     & -783, -793, -803, -806, -804, -807, -788, -752, -694, -610,! 8.00
     & -504, -376, -232,  -76,   87,  258,  435,  614,  789,  959,! 8.00
     & 1124, 1357, 1566, 1742, 1889, 2031, 2189, 2359, 2534, 2706,! 8.00
     & 2888, 3178, 3466, 3758, 4027, 4261, 4442, 4556, 4594, 4563,! 8.00
     & 4484, 4364, 4213, 4014, 3783, 3534, 3292, 3040, 2783, 2548,! 8.00
     & 2318, 2094, 1886, 1693, 1503, 1303, 1093/                  ! 8.00

      end module ross_tables

!***********************************************************************
